from typing import Any

from ..cmd import Command

def show_compilers() -> None: ...

class build(Command):
    description: str
    user_options: Any
    boolean_options: Any
    help_options: Any
    build_base: str
    build_purelib: Any
    build_platlib: Any
    build_lib: Any
    build_temp: Any
    build_scripts: Any
    compiler: Any
    plat_name: Any
    debug: Any
    force: int
    executable: Any
    parallel: Any
    def initialize_options(self) -> None: ...
    def finalize_options(self) -> None: ...
    def run(self) -> None: ...
    def has_pure_modules(self): ...
    def has_c_libraries(self): ...
    def has_ext_modules(self): ...
    def has_scripts(self): ...
    sub_commands: Any



from socket import _RetAddress, socket
from threading import Thread
from typing import Protocol

from paramiko.channel import Channel
from paramiko.message import Message
from paramiko.pkey import PKey
from paramiko.transport import Transport

class _AgentProxy(Protocol):
    def connect(self) -> None: ...
    def close(self) -> None: ...

cSSH2_AGENTC_REQUEST_IDENTITIES: bytes
SSH2_AGENT_IDENTITIES_ANSWER: int
cSSH2_AGENTC_SIGN_REQUEST: bytes
SSH2_AGENT_SIGN_RESPONSE: int

class AgentSSH:
    def __init__(self) -> None: ...
    def get_keys(self) -> tuple[AgentKey, ...]: ...

class AgentProxyThread(Thread):
    def __init__(self, agent: _AgentProxy) -> None: ...
    def run(self) -> None: ...

class AgentLocalProxy(AgentProxyThread):
    def __init__(self, agent: AgentServerProxy) -> None: ...
    def get_connection(self) -> tuple[socket, _RetAddress]: ...

class AgentRemoteProxy(AgentProxyThread):
    def __init__(self, agent: AgentClientProxy, chan: Channel) -> None: ...
    def get_connection(self) -> tuple[socket, _RetAddress]: ...

class AgentClientProxy:
    thread: Thread
    def __init__(self, chanRemote: Channel) -> None: ...
    def __del__(self) -> None: ...
    def connect(self) -> None: ...
    def close(self) -> None: ...

class AgentServerProxy(AgentSSH):
    thread: Thread
    def __init__(self, t: Transport) -> None: ...
    def __del__(self) -> None: ...
    def connect(self) -> None: ...
    def close(self) -> None: ...
    def get_env(self) -> dict[str, str]: ...

class AgentRequestHandler:
    def __init__(self, chanClient: Channel) -> None: ...
    def __del__(self) -> None: ...
    def close(self) -> None: ...

class Agent(AgentSSH):
    def __init__(self) -> None: ...
    def close(self) -> None: ...

class AgentKey(PKey):
    agent: AgentSSH
    blob: bytes
    public_blob: None
    name: str
    def __init__(self, agent: AgentSSH, blob: bytes) -> None: ...
    def asbytes(self) -> bytes: ...
    def get_name(self) -> str: ...
    def sign_ssh_data(self, data: bytes, algorithm: str | None = ...) -> Message: ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class PrintPageSetup(Serialisable):
    tagname: str
    orientation: Any
    paperSize: Any
    scale: Any
    fitToHeight: Any
    fitToWidth: Any
    firstPageNumber: Any
    useFirstPageNumber: Any
    paperHeight: Any
    paperWidth: Any
    pageOrder: Any
    usePrinterDefaults: Any
    blackAndWhite: Any
    draft: Any
    cellComments: Any
    errors: Any
    horizontalDpi: Any
    verticalDpi: Any
    copies: Any
    id: Any
    def __init__(
        self,
        worksheet: Any | None = ...,
        orientation: Any | None = ...,
        paperSize: Any | None = ...,
        scale: Any | None = ...,
        fitToHeight: Any | None = ...,
        fitToWidth: Any | None = ...,
        firstPageNumber: Any | None = ...,
        useFirstPageNumber: Any | None = ...,
        paperHeight: Any | None = ...,
        paperWidth: Any | None = ...,
        pageOrder: Any | None = ...,
        usePrinterDefaults: Any | None = ...,
        blackAndWhite: Any | None = ...,
        draft: Any | None = ...,
        cellComments: Any | None = ...,
        errors: Any | None = ...,
        horizontalDpi: Any | None = ...,
        verticalDpi: Any | None = ...,
        copies: Any | None = ...,
        id: Any | None = ...,
    ) -> None: ...
    def __bool__(self): ...
    @property
    def sheet_properties(self): ...
    @property
    def fitToPage(self): ...
    @fitToPage.setter
    def fitToPage(self, value) -> None: ...
    @property
    def autoPageBreaks(self): ...
    @autoPageBreaks.setter
    def autoPageBreaks(self, value) -> None: ...
    @classmethod
    def from_tree(cls, node): ...

class PrintOptions(Serialisable):
    tagname: str
    horizontalCentered: Any
    verticalCentered: Any
    headings: Any
    gridLines: Any
    gridLinesSet: Any
    def __init__(
        self,
        horizontalCentered: Any | None = ...,
        verticalCentered: Any | None = ...,
        headings: Any | None = ...,
        gridLines: Any | None = ...,
        gridLinesSet: Any | None = ...,
    ) -> None: ...
    def __bool__(self): ...

class PageMargins(Serialisable):
    tagname: str
    left: Any
    right: Any
    top: Any
    bottom: Any
    header: Any
    footer: Any
    def __init__(
        self, left: float = ..., right: float = ..., top: int = ..., bottom: int = ..., header: float = ..., footer: float = ...
    ) -> None: ...



from typing import Any

entitiesTrie: Any
attributeMap = dict

class HTMLTokenizer:
    stream: Any
    parser: Any
    escapeFlag: bool
    lastFourChars: Any
    state: Any
    escape: bool
    currentToken: Any
    def __init__(self, stream, parser: Any | None = ..., **kwargs) -> None: ...
    tokenQueue: Any
    def __iter__(self): ...
    def consumeNumberEntity(self, isHex): ...
    def consumeEntity(self, allowedChar: Any | None = ..., fromAttribute: bool = ...) -> None: ...
    def processEntityInAttribute(self, allowedChar) -> None: ...
    def emitCurrentToken(self) -> None: ...
    def dataState(self): ...
    def entityDataState(self): ...
    def rcdataState(self): ...
    def characterReferenceInRcdata(self): ...
    def rawtextState(self): ...
    def scriptDataState(self): ...
    def plaintextState(self): ...
    def tagOpenState(self): ...
    def closeTagOpenState(self): ...
    def tagNameState(self): ...
    temporaryBuffer: str
    def rcdataLessThanSignState(self): ...
    def rcdataEndTagOpenState(self): ...
    def rcdataEndTagNameState(self): ...
    def rawtextLessThanSignState(self): ...
    def rawtextEndTagOpenState(self): ...
    def rawtextEndTagNameState(self): ...
    def scriptDataLessThanSignState(self): ...
    def scriptDataEndTagOpenState(self): ...
    def scriptDataEndTagNameState(self): ...
    def scriptDataEscapeStartState(self): ...
    def scriptDataEscapeStartDashState(self): ...
    def scriptDataEscapedState(self): ...
    def scriptDataEscapedDashState(self): ...
    def scriptDataEscapedDashDashState(self): ...
    def scriptDataEscapedLessThanSignState(self): ...
    def scriptDataEscapedEndTagOpenState(self): ...
    def scriptDataEscapedEndTagNameState(self): ...
    def scriptDataDoubleEscapeStartState(self): ...
    def scriptDataDoubleEscapedState(self): ...
    def scriptDataDoubleEscapedDashState(self): ...
    def scriptDataDoubleEscapedDashDashState(self): ...
    def scriptDataDoubleEscapedLessThanSignState(self): ...
    def scriptDataDoubleEscapeEndState(self): ...
    def beforeAttributeNameState(self): ...
    def attributeNameState(self): ...
    def afterAttributeNameState(self): ...
    def beforeAttributeValueState(self): ...
    def attributeValueDoubleQuotedState(self): ...
    def attributeValueSingleQuotedState(self): ...
    def attributeValueUnQuotedState(self): ...
    def afterAttributeValueState(self): ...
    def selfClosingStartTagState(self): ...
    def bogusCommentState(self): ...
    def markupDeclarationOpenState(self): ...
    def commentStartState(self): ...
    def commentStartDashState(self): ...
    def commentState(self): ...
    def commentEndDashState(self): ...
    def commentEndState(self): ...
    def commentEndBangState(self): ...
    def doctypeState(self): ...
    def beforeDoctypeNameState(self): ...
    def doctypeNameState(self): ...
    def afterDoctypeNameState(self): ...
    def afterDoctypePublicKeywordState(self): ...
    def beforeDoctypePublicIdentifierState(self): ...
    def doctypePublicIdentifierDoubleQuotedState(self): ...
    def doctypePublicIdentifierSingleQuotedState(self): ...
    def afterDoctypePublicIdentifierState(self): ...
    def betweenDoctypePublicAndSystemIdentifiersState(self): ...
    def afterDoctypeSystemKeywordState(self): ...
    def beforeDoctypeSystemIdentifierState(self): ...
    def doctypeSystemIdentifierDoubleQuotedState(self): ...
    def doctypeSystemIdentifierSingleQuotedState(self): ...
    def afterDoctypeSystemIdentifierState(self): ...
    def bogusDoctypeState(self): ...
    def cdataSectionState(self): ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class ChartRelation(Serialisable):
    tagname: str
    namespace: Any
    id: Any
    def __init__(self, id) -> None: ...



from typing import Any

from .connection import S3Connection
from .user import User

CannedACLStrings: list[str]

class Policy:
    parent: Any
    namespace: Any
    acl: ACL
    def __init__(self, parent: Any | None = ...) -> None: ...
    owner: User
    def startElement(self, name: str, attrs: dict[str, Any], connection: S3Connection) -> None | User | ACL: ...
    def endElement(self, name: str, value: Any, connection: S3Connection) -> None: ...
    def to_xml(self) -> str: ...

class ACL:
    policy: Policy
    grants: list[Grant]
    def __init__(self, policy: Policy | None = ...) -> None: ...
    def add_grant(self, grant: Grant) -> None: ...
    def add_email_grant(self, permission: str, email_address: str) -> None: ...
    def add_user_grant(self, permission: str, user_id: str, display_name: str | None = ...) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name: str, value: Any, connection: S3Connection) -> None: ...
    def to_xml(self) -> str: ...

class Grant:
    NameSpace: str
    permission: str
    id: str
    display_name: str
    uri: str
    email_address: str
    type: str
    def __init__(
        self,
        permission: str | None = ...,
        type: str | None = ...,
        id: str | None = ...,
        display_name: str | None = ...,
        uri: str | None = ...,
        email_address: str | None = ...,
    ) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name: str, value: Any, connection: S3Connection) -> None: ...
    def to_xml(self) -> str: ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class BookView(Serialisable):
    tagname: str
    visibility: Any
    minimized: Any
    showHorizontalScroll: Any
    showVerticalScroll: Any
    showSheetTabs: Any
    xWindow: Any
    yWindow: Any
    windowWidth: Any
    windowHeight: Any
    tabRatio: Any
    firstSheet: Any
    activeTab: Any
    autoFilterDateGrouping: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        visibility: str = ...,
        minimized: bool = ...,
        showHorizontalScroll: bool = ...,
        showVerticalScroll: bool = ...,
        showSheetTabs: bool = ...,
        xWindow: Any | None = ...,
        yWindow: Any | None = ...,
        windowWidth: Any | None = ...,
        windowHeight: Any | None = ...,
        tabRatio: int = ...,
        firstSheet: int = ...,
        activeTab: int = ...,
        autoFilterDateGrouping: bool = ...,
        extLst: Any | None = ...,
    ) -> None: ...

class CustomWorkbookView(Serialisable):
    tagname: str
    name: Any
    guid: Any
    autoUpdate: Any
    mergeInterval: Any
    changesSavedWin: Any
    onlySync: Any
    personalView: Any
    includePrintSettings: Any
    includeHiddenRowCol: Any
    maximized: Any
    minimized: Any
    showHorizontalScroll: Any
    showVerticalScroll: Any
    showSheetTabs: Any
    xWindow: Any
    yWindow: Any
    windowWidth: Any
    windowHeight: Any
    tabRatio: Any
    activeSheetId: Any
    showFormulaBar: Any
    showStatusbar: Any
    showComments: Any
    showObjects: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        name: Any | None = ...,
        guid: Any | None = ...,
        autoUpdate: Any | None = ...,
        mergeInterval: Any | None = ...,
        changesSavedWin: Any | None = ...,
        onlySync: Any | None = ...,
        personalView: Any | None = ...,
        includePrintSettings: Any | None = ...,
        includeHiddenRowCol: Any | None = ...,
        maximized: Any | None = ...,
        minimized: Any | None = ...,
        showHorizontalScroll: Any | None = ...,
        showVerticalScroll: Any | None = ...,
        showSheetTabs: Any | None = ...,
        xWindow: Any | None = ...,
        yWindow: Any | None = ...,
        windowWidth: Any | None = ...,
        windowHeight: Any | None = ...,
        tabRatio: Any | None = ...,
        activeSheetId: Any | None = ...,
        showFormulaBar: Any | None = ...,
        showStatusbar: Any | None = ...,
        showComments: str = ...,
        showObjects: str = ...,
        extLst: Any | None = ...,
    ) -> None: ...



from types import TracebackType
from typing import Any

GLYPHS: Any
MINIMUM_INTERVAL: float

class Spinner:
    interactive: Any
    interval: Any
    label: Any
    states: Any
    stream: Any
    timer: Any
    total: Any
    counter: int
    last_update: int
    def __init__(self, **options) -> None: ...
    def step(self, progress: int = ..., label: Any | None = ...) -> None: ...
    def sleep(self) -> None: ...
    def clear(self) -> None: ...
    def __enter__(self): ...
    def __exit__(
        self,
        exc_type: type[BaseException] | None = ...,
        exc_value: BaseException | None = ...,
        traceback: TracebackType | None = ...,
    ) -> None: ...

class AutomaticSpinner:
    label: Any
    show_time: Any
    shutdown_event: Any
    subprocess: Any
    def __init__(self, label, show_time: bool = ...) -> None: ...
    def __enter__(self) -> None: ...
    def __exit__(
        self,
        exc_type: type[BaseException] | None = ...,
        exc_value: BaseException | None = ...,
        traceback: TracebackType | None = ...,
    ) -> None: ...



from typing import Any

from braintree.configuration import Configuration as Configuration
from braintree.merchant_account import (
    BusinessDetails as BusinessDetails,
    FundingDetails as FundingDetails,
    IndividualDetails as IndividualDetails,
)
from braintree.resource import Resource as Resource

class MerchantAccount(Resource):
    class Status:
        Active: str
        Pending: str
        Suspended: str

    class FundingDestination:
        Bank: str
        Email: str
        MobilePhone: str
    FundingDestinations: Any
    individual_details: Any
    business_details: Any
    funding_details: Any
    master_merchant_account: Any
    def __init__(self, gateway, attributes) -> None: ...
    @staticmethod
    def create(params: Any | None = ...): ...
    @staticmethod
    def update(id, attributes): ...
    @staticmethod
    def find(id): ...



from typing import Any
from typing_extensions import TypeAlias

# Enable when pyasn1 gets stubs:
# from pyasn1.type import univ
_Sequence: TypeAlias = Any

RSA_ENCRYPTION_ASN1_OID: str

class RsaAlgorithmIdentifier(_Sequence):
    componentType: Any

class PKCS8PrivateKey(_Sequence):
    componentType: Any

class PublicKeyInfo(_Sequence):
    componentType: Any

def rsa_private_key_pkcs8_to_pkcs1(pkcs8_key): ...
def rsa_private_key_pkcs1_to_pkcs8(pkcs1_key): ...
def rsa_public_key_pkcs1_to_pkcs8(pkcs1_key): ...
def rsa_public_key_pkcs8_to_pkcs1(pkcs8_key): ...



from typing import Any

import sqlalchemy.types as sqltypes

class _NumericType:
    unsigned: Any
    zerofill: Any
    def __init__(self, unsigned: bool = ..., zerofill: bool = ..., **kw) -> None: ...

class _FloatType(_NumericType, sqltypes.Float):
    scale: Any
    def __init__(self, precision: Any | None = ..., scale: Any | None = ..., asdecimal: bool = ..., **kw) -> None: ...

class _IntegerType(_NumericType, sqltypes.Integer):
    display_width: Any
    def __init__(self, display_width: Any | None = ..., **kw) -> None: ...

class _StringType(sqltypes.String):
    charset: Any
    ascii: Any
    unicode: Any
    binary: Any
    national: Any
    def __init__(
        self,
        charset: Any | None = ...,
        collation: Any | None = ...,
        ascii: bool = ...,
        binary: bool = ...,
        unicode: bool = ...,
        national: bool = ...,
        **kw,
    ) -> None: ...

class _MatchType(sqltypes.Float, sqltypes.MatchType):  # type: ignore[misc]  # incompatible with base class
    def __init__(self, **kw) -> None: ...

class NUMERIC(_NumericType, sqltypes.NUMERIC):
    __visit_name__: str
    def __init__(self, precision: Any | None = ..., scale: Any | None = ..., asdecimal: bool = ..., **kw) -> None: ...

class DECIMAL(_NumericType, sqltypes.DECIMAL):
    __visit_name__: str
    def __init__(self, precision: Any | None = ..., scale: Any | None = ..., asdecimal: bool = ..., **kw) -> None: ...

class DOUBLE(_FloatType):
    __visit_name__: str
    def __init__(self, precision: Any | None = ..., scale: Any | None = ..., asdecimal: bool = ..., **kw) -> None: ...

class REAL(_FloatType, sqltypes.REAL):
    __visit_name__: str
    def __init__(self, precision: Any | None = ..., scale: Any | None = ..., asdecimal: bool = ..., **kw) -> None: ...

class FLOAT(_FloatType, sqltypes.FLOAT):
    __visit_name__: str
    def __init__(self, precision: Any | None = ..., scale: Any | None = ..., asdecimal: bool = ..., **kw) -> None: ...
    def bind_processor(self, dialect) -> None: ...

class INTEGER(_IntegerType, sqltypes.INTEGER):
    __visit_name__: str
    def __init__(self, display_width: Any | None = ..., **kw) -> None: ...

class BIGINT(_IntegerType, sqltypes.BIGINT):
    __visit_name__: str
    def __init__(self, display_width: Any | None = ..., **kw) -> None: ...

class MEDIUMINT(_IntegerType):
    __visit_name__: str
    def __init__(self, display_width: Any | None = ..., **kw) -> None: ...

class TINYINT(_IntegerType):
    __visit_name__: str
    def __init__(self, display_width: Any | None = ..., **kw) -> None: ...

class SMALLINT(_IntegerType, sqltypes.SMALLINT):
    __visit_name__: str
    def __init__(self, display_width: Any | None = ..., **kw) -> None: ...

class BIT(sqltypes.TypeEngine):
    __visit_name__: str
    length: Any
    def __init__(self, length: Any | None = ...) -> None: ...
    def result_processor(self, dialect, coltype): ...

class TIME(sqltypes.TIME):
    __visit_name__: str
    fsp: Any
    def __init__(self, timezone: bool = ..., fsp: Any | None = ...) -> None: ...
    def result_processor(self, dialect, coltype): ...

class TIMESTAMP(sqltypes.TIMESTAMP):
    __visit_name__: str
    fsp: Any
    def __init__(self, timezone: bool = ..., fsp: Any | None = ...) -> None: ...

class DATETIME(sqltypes.DATETIME):
    __visit_name__: str
    fsp: Any
    def __init__(self, timezone: bool = ..., fsp: Any | None = ...) -> None: ...

class YEAR(sqltypes.TypeEngine):
    __visit_name__: str
    display_width: Any
    def __init__(self, display_width: Any | None = ...) -> None: ...

class TEXT(_StringType, sqltypes.TEXT):
    __visit_name__: str
    def __init__(self, length: Any | None = ..., **kw) -> None: ...

class TINYTEXT(_StringType):
    __visit_name__: str
    def __init__(self, **kwargs) -> None: ...

class MEDIUMTEXT(_StringType):
    __visit_name__: str
    def __init__(self, **kwargs) -> None: ...

class LONGTEXT(_StringType):
    __visit_name__: str
    def __init__(self, **kwargs) -> None: ...

class VARCHAR(_StringType, sqltypes.VARCHAR):
    __visit_name__: str
    def __init__(self, length: Any | None = ..., **kwargs) -> None: ...

class CHAR(_StringType, sqltypes.CHAR):
    __visit_name__: str
    def __init__(self, length: Any | None = ..., **kwargs) -> None: ...

class NVARCHAR(_StringType, sqltypes.NVARCHAR):
    __visit_name__: str
    def __init__(self, length: Any | None = ..., **kwargs) -> None: ...

class NCHAR(_StringType, sqltypes.NCHAR):
    __visit_name__: str
    def __init__(self, length: Any | None = ..., **kwargs) -> None: ...

class TINYBLOB(sqltypes._Binary):
    __visit_name__: str

class MEDIUMBLOB(sqltypes._Binary):
    __visit_name__: str

class LONGBLOB(sqltypes._Binary):
    __visit_name__: str



from typing import Any

from .fault import *
from .query import *

class DynamicData: ...

class DynamicProperty:
    def __init__(self, *, name: str = ..., val: Any = ...) -> None: ...
    name: str
    val: Any

class ManagedObject: ...

class KeyAnyValue(DynamicData):
    key: str
    value: Any

class LocalizableMessage(DynamicData):
    key: str
    arg: list[KeyAnyValue] | None
    message: str | None

class MethodFault(DynamicData, Exception):
    msg: str | None
    faultCause: MethodFault | None
    faultMessage: list[LocalizableMessage] | None



import sys
import types
from _typeshed import Incomplete, ReadableBuffer, WriteableBuffer
from collections.abc import Callable, Hashable
from typing import Any, ClassVar, Protocol, TypeVar, overload
from typing_extensions import Literal, TypeAlias, final

_T = TypeVar("_T")

class _Allocator(Protocol):
    def __call__(self, cdecl: str | CType, init: Any = ...) -> _CDataBase: ...

__version__: str

FFI_CDECL: int
FFI_DEFAULT_ABI: int
RTLD_GLOBAL: int
RTLD_LAZY: int
RTLD_LOCAL: int
RTLD_NOW: int
if sys.platform != "win32":
    RTLD_DEEPBIND: int
    RTLD_NODELETE: int
    RTLD_NOLOAD: int

@final
class CField:
    bitshift: Incomplete
    bitsize: Incomplete
    flags: Incomplete
    offset: Incomplete
    type: Incomplete

@final
class CLibrary:
    def close_lib(self, *args, **kwargs): ...
    def load_function(self, *args, **kwargs): ...
    def read_variable(self, *args, **kwargs): ...
    def write_variable(self, *args, **kwargs): ...

@final
class CType:
    abi: Incomplete
    args: Incomplete
    cname: Incomplete
    elements: Incomplete
    ellipsis: Incomplete
    fields: Incomplete
    item: Incomplete
    kind: Incomplete
    length: Incomplete
    relements: Incomplete
    result: Incomplete
    def __dir__(self): ...

@final
class Lib:
    def __dir__(self): ...

@final
class _CDataBase:
    __name__: ClassVar[str]
    def __add__(self, other): ...
    def __bool__(self): ...
    def __call__(self, *args, **kwargs): ...
    def __complex__(self): ...
    def __delitem__(self, other): ...
    def __dir__(self): ...
    def __enter__(self): ...
    def __eq__(self, other): ...
    def __exit__(self, type, value, traceback): ...
    def __float__(self): ...
    def __ge__(self, other): ...
    def __getitem__(self, index): ...
    def __gt__(self, other): ...
    def __hash__(self): ...
    def __int__(self): ...
    def __iter__(self): ...
    def __le__(self, other): ...
    def __len__(self): ...
    def __lt__(self, other): ...
    def __ne__(self, other): ...
    def __radd__(self, other): ...
    def __rsub__(self, other): ...
    def __setitem__(self, index, object): ...
    def __sub__(self, other): ...

@final
class buffer:
    __hash__: ClassVar[None]  # type: ignore[assignment]
    def __init__(self, *args, **kwargs) -> None: ...
    def __delitem__(self, other): ...
    def __eq__(self, other): ...
    def __ge__(self, other): ...
    def __getitem__(self, index): ...
    def __gt__(self, other): ...
    def __le__(self, other): ...
    def __len__(self): ...
    def __lt__(self, other): ...
    def __ne__(self, other): ...
    def __setitem__(self, index, object): ...

# These aliases are to work around pyright complaints.
# Pyright doesn't like it when a class object is defined as an alias
# of a global object with the same name.
_tmp_CType = CType
_tmp_buffer = buffer

class FFI:
    CData: TypeAlias = _CDataBase
    CType: TypeAlias = _tmp_CType
    buffer: TypeAlias = _tmp_buffer  # noqa: Y042

    class error(Exception): ...
    NULL: ClassVar[CData]
    RTLD_GLOBAL: ClassVar[int]
    RTLD_LAZY: ClassVar[int]
    RTLD_LOCAL: ClassVar[int]
    RTLD_NOW: ClassVar[int]
    if sys.platform != "win32":
        RTLD_DEEPBIND: ClassVar[int]
        RTLD_NODELETE: ClassVar[int]
        RTLD_NOLOAD: ClassVar[int]

    errno: int

    def __init__(
        self,
        module_name: str = ...,
        _version: int = ...,
        _types: str = ...,
        _globals: tuple[str | int, ...] = ...,
        _struct_unions: tuple[tuple[str, ...], ...] = ...,
        _enums: tuple[str, ...] = ...,
        _typenames: tuple[str, ...] = ...,
        _includes: tuple[FFI, ...] = ...,
    ) -> None: ...
    @overload
    def addressof(self, __cdata: CData, *field_or_index: str | int) -> CData: ...
    @overload
    def addressof(self, __library: Lib, __name: str) -> CData: ...
    def alignof(self, __cdecl: str | CType | CData) -> int: ...
    @overload
    def callback(
        self,
        cdecl: str | CType,
        python_callable: None = ...,
        error: Any = ...,
        onerror: Callable[[Exception, Any, Any], None] | None = ...,
    ) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    @overload
    def callback(
        self,
        cdecl: str | CType,
        python_callable: Callable[..., _T],
        error: Any = ...,
        onerror: Callable[[Exception, Any, Any], None] | None = ...,
    ) -> Callable[..., _T]: ...
    def cast(self, cdecl: str | CType, value: CData) -> CData: ...
    def def_extern(
        self, name: str = ..., error: Any = ..., onerror: Callable[[Exception, Any, types.TracebackType], Any] = ...
    ) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    def dlclose(self, __lib: Lib) -> None: ...
    if sys.platform == "win32":
        def dlopen(self, __libpath: str | CData, __flags: int = ...) -> Lib: ...
    else:
        def dlopen(self, __libpath: str | CData | None = ..., __flags: int = ...) -> Lib: ...

    @overload
    def from_buffer(self, cdecl: ReadableBuffer, require_writable: Literal[False] = ...) -> CData: ...
    @overload
    def from_buffer(self, cdecl: WriteableBuffer, require_writable: Literal[True]) -> CData: ...
    @overload
    def from_buffer(self, cdecl: str | CType, python_buffer: ReadableBuffer, require_writable: Literal[False] = ...) -> CData: ...
    @overload
    def from_buffer(self, cdecl: str | CType, python_buffer: WriteableBuffer, require_writable: Literal[True]) -> CData: ...
    def from_handle(self, __x: CData) -> Any: ...
    @overload
    def gc(self, cdata: CData, destructor: Callable[[CData], Any], size: int = ...) -> CData: ...
    @overload
    def gc(self, cdata: CData, destructor: None, size: int = ...) -> None: ...
    def getctype(self, cdecl: str | CType, replace_with: str = ...) -> str: ...
    if sys.platform == "win32":
        def getwinerror(self, code: int = ...) -> tuple[int, str]: ...

    def init_once(self, func: Callable[[], Any], tag: Hashable) -> Any: ...
    def integer_const(self, name: str) -> int: ...
    def list_types(self) -> tuple[list[str], list[str], list[str]]: ...
    def memmove(self, dest: CData | WriteableBuffer, src: CData | ReadableBuffer, n: int) -> None: ...
    def new(self, cdecl: str | CType, init: Any = ...) -> CData: ...
    @overload
    def new_allocator(self, alloc: None = ..., free: None = ..., should_clear_after_alloc: bool = ...) -> _Allocator: ...
    @overload
    def new_allocator(
        self, alloc: Callable[[int], CData], free: None = ..., should_clear_after_alloc: bool = ...
    ) -> _Allocator: ...
    @overload
    def new_allocator(
        self, alloc: Callable[[int], CData], free: Callable[[CData], Any], should_clear_after_alloc: bool = ...
    ) -> _Allocator: ...
    def new_handle(self, __x: Any) -> CData: ...
    def offsetof(self, __cdecl: str | CType, __field_or_index: str | int, *__fields_or_indexes: str | int) -> int: ...
    def release(self, __cdata: CData) -> None: ...
    def sizeof(self, __cdecl: str | CType | CData) -> int: ...
    def string(self, cdata: CData, maxlen: int) -> bytes | str: ...
    def typeof(self, cdecl: str | CData) -> CType: ...
    def unpack(self, cdata: CData, length: int) -> bytes | str | list[Any]: ...

def alignof(__cdecl: CType) -> int: ...
def callback(
    __cdecl: CType,
    __python_callable: Callable[..., _T],
    __error: Any = ...,
    __onerror: Callable[[Exception, Any, Any], None] | None = ...,
) -> Callable[..., _T]: ...
def cast(__cdecl: CType, __value: _CDataBase) -> _CDataBase: ...
def complete_struct_or_union(
    __cdecl: CType,
    __fields: list[tuple[str, CType, int, int]],
    __ignored: Any,
    __total_size: int,
    __total_alignment: int,
    __sflags: int,
    __pack: int,
) -> None: ...
@overload
def from_buffer(__cdecl: CType, __python_buffer: ReadableBuffer, require_writable: Literal[False] = ...) -> _CDataBase: ...
@overload
def from_buffer(__cdecl: CType, __python_buffer: WriteableBuffer, require_writable: Literal[True]) -> _CDataBase: ...
def from_handle(__x: _CDataBase) -> Any: ...
@overload
def gcp(cdata: _CDataBase, destructor: Callable[[_CDataBase], Any], size: int = ...) -> _CDataBase: ...
@overload
def gcp(cdata: _CDataBase, destructor: None, size: int = ...) -> None: ...
def get_errno() -> int: ...
def getcname(__cdecl: CType, __replace_with: str) -> str: ...

if sys.platform == "win32":
    def getwinerror(code: int = ...) -> tuple[int, str]: ...

if sys.platform == "win32":
    def load_library(__libpath: str | _CDataBase, __flags: int = ...) -> CLibrary: ...

else:
    def load_library(__libpath: str | _CDataBase | None = ..., __flags: int = ...) -> CLibrary: ...

def memmove(dest: _CDataBase | WriteableBuffer, src: _CDataBase | ReadableBuffer, n: int) -> None: ...
def new_array_type(__cdecl: CType, __length: int | None) -> CType: ...
def new_enum_type(__name: str, __enumerators: tuple[str, ...], __enumvalues: tuple[Any, ...], __basetype: CType) -> CType: ...
def new_function_type(__args: tuple[CType, ...], __result: CType, __ellipsis: int, __abi: int) -> CType: ...
def new_pointer_type(__cdecl: CType) -> CType: ...
def new_primitive_type(__name: str) -> CType: ...
def new_struct_type(__name: str) -> CType: ...
def new_union_type(__name: str) -> CType: ...
def new_void_type() -> CType: ...
def newp(__cdecl: CType, __init: Any = ...) -> _CDataBase: ...
def newp_handle(__cdecl: CType, __x: Any) -> _CDataBase: ...
def rawaddressof(__cdecl: CType, __cdata: _CDataBase, __offset: int) -> _CDataBase: ...
def release(__cdata: _CDataBase) -> None: ...
def set_errno(__errno: int) -> None: ...
def sizeof(__cdecl: CType | _CDataBase) -> int: ...
def string(cdata: _CDataBase, maxlen: int) -> bytes | str: ...
def typeof(__cdata: _CDataBase) -> CType: ...
def typeoffsetof(__cdecl: CType, __fieldname: str | int, __following: bool = ...) -> tuple[CType, int]: ...
def unpack(cdata: _CDataBase, length: int) -> bytes | str | list[Any]: ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class WebPublishObject(Serialisable):
    tagname: str
    id: Any
    divId: Any
    sourceObject: Any
    destinationFile: Any
    title: Any
    autoRepublish: Any
    def __init__(
        self,
        id: Any | None = ...,
        divId: Any | None = ...,
        sourceObject: Any | None = ...,
        destinationFile: Any | None = ...,
        title: Any | None = ...,
        autoRepublish: Any | None = ...,
    ) -> None: ...

class WebPublishObjectList(Serialisable):
    tagname: str
    # Overwritten by property below
    # count: Integer
    webPublishObject: Any
    __elements__: Any
    def __init__(self, count: Any | None = ..., webPublishObject=...) -> None: ...
    @property
    def count(self): ...

class WebPublishing(Serialisable):
    tagname: str
    css: Any
    thicket: Any
    longFileNames: Any
    vml: Any
    allowPng: Any
    targetScreenSize: Any
    dpi: Any
    codePage: Any
    characterSet: Any
    def __init__(
        self,
        css: Any | None = ...,
        thicket: Any | None = ...,
        longFileNames: Any | None = ...,
        vml: Any | None = ...,
        allowPng: Any | None = ...,
        targetScreenSize: str = ...,
        dpi: Any | None = ...,
        codePage: Any | None = ...,
        characterSet: Any | None = ...,
    ) -> None: ...



import datetime
from _typeshed import Incomplete, Self
from collections.abc import Iterable, Iterator, Mapping, Sequence
from typing import Any, TypeVar, overload
from typing_extensions import Literal, TypeAlias
from urllib.parse import ParseResult, SplitResult

from vobject.base import VBase

from .davclient import DAVClient
from .elements.cdav import CalendarQuery, CompFilter, ScheduleInboxURL, ScheduleOutboxURL
from .lib.url import URL

_CC = TypeVar("_CC", bound=CalendarObjectResource)
# Actually "type[Todo] | type[Event] | type[Journal]", but mypy doesn't like that.
_CompClass: TypeAlias = type[CalendarObjectResource]
_VCalAddress: TypeAlias = Any  # actually icalendar.vCalAddress

class DAVObject:
    id: str | None
    url: URL | None
    client: DAVClient | None
    parent: DAVObject | None
    name: str | None
    props: Mapping[Any, Any]
    extra_init_options: dict[str, Any]
    def __init__(
        self,
        client: DAVClient | None = ...,
        url: str | ParseResult | SplitResult | URL | None = ...,
        parent: DAVObject | None = ...,
        name: str | None = ...,
        id: str | None = ...,
        props: Mapping[Any, Any] | None = ...,
        **extra: Any,
    ) -> None: ...
    @property
    def canonical_url(self) -> str: ...
    def children(self, type: str | None = ...) -> list[tuple[URL, Any, Any]]: ...
    def get_property(self, prop, use_cached: bool = ..., **passthrough) -> Any | None: ...
    def get_properties(
        self, props: Any | None = ..., depth: int = ..., parse_response_xml: bool = ..., parse_props: bool = ...
    ): ...
    def set_properties(self: Self, props: Any | None = ...) -> Self: ...
    def save(self: Self) -> Self: ...
    def delete(self) -> None: ...

class CalendarSet(DAVObject):
    def calendars(self) -> list[Calendar]: ...
    def make_calendar(
        self, name: str | None = ..., cal_id: str | None = ..., supported_calendar_component_set: Any | None = ...
    ) -> Calendar: ...
    def calendar(self, name: str | None = ..., cal_id: str | None = ...) -> Calendar: ...

class Principal(DAVObject):
    def __init__(self, client: DAVClient | None = ..., url: str | ParseResult | SplitResult | URL | None = ...) -> None: ...
    def calendars(self) -> list[Calendar]: ...
    def make_calendar(
        self, name: str | None = ..., cal_id: str | None = ..., supported_calendar_component_set: Any | None = ...
    ) -> Calendar: ...
    def calendar(self, name: str | None = ..., cal_id: str | None = ...) -> Calendar: ...
    def get_vcal_address(self) -> _VCalAddress: ...
    calendar_home_set: CalendarSet  # can also be set to anything URL.objectify() accepts
    def freebusy_request(self, dtstart, dtend, attendees): ...
    def calendar_user_address_set(self) -> list[str]: ...
    def schedule_inbox(self) -> ScheduleInbox: ...
    def schedule_outbox(self) -> ScheduleOutbox: ...

class Calendar(DAVObject):
    def get_supported_components(self) -> list[Any]: ...
    def save_with_invites(self, ical: str, attendees, **attendeeoptions) -> None: ...
    def save_event(self, ical: str | None = ..., no_overwrite: bool = ..., no_create: bool = ..., **ical_data: Any) -> Event: ...
    def save_todo(self, ical: str | None = ..., no_overwrite: bool = ..., no_create: bool = ..., **ical_data: Any) -> Todo: ...
    def save_journal(
        self, ical: str | None = ..., no_overwrite: bool = ..., no_create: bool = ..., **ical_data: Any
    ) -> Journal: ...
    add_event = save_event
    add_todo = save_todo
    add_journal = save_journal
    def calendar_multiget(self, event_urls: Iterable[URL]) -> list[Event]: ...
    def build_date_search_query(
        self,
        start,
        end: datetime.datetime | None = ...,
        compfilter: Literal["VEVENT"] | None = ...,
        expand: bool | Literal["maybe"] = ...,
    ): ...
    @overload
    def date_search(
        self,
        start: datetime.datetime,
        end: datetime.datetime | None = ...,
        compfilter: Literal["VEVENT"] = ...,
        expand: bool | Literal["maybe"] = ...,
        verify_expand: bool = ...,
    ) -> list[Event]: ...
    @overload
    def date_search(
        self, start: datetime.datetime, *, compfilter: None, expand: bool | Literal["maybe"] = ..., verify_expand: bool = ...
    ) -> list[CalendarObjectResource]: ...
    @overload
    def date_search(
        self,
        start: datetime.datetime,
        end: datetime.datetime | None,
        compfilter: None,
        expand: bool | Literal["maybe"] = ...,
        verify_expand: bool = ...,
    ) -> list[CalendarObjectResource]: ...
    @overload
    def search(
        self,
        xml: None = ...,
        comp_class: None = ...,
        todo: bool | None = ...,
        include_completed: bool = ...,
        sort_keys: Sequence[str] = ...,
        **kwargs,
    ) -> list[CalendarObjectResource]: ...
    @overload
    def search(
        self,
        xml,
        comp_class: type[_CC],
        todo: bool | None = ...,
        include_completed: bool = ...,
        sort_keys: Sequence[str] = ...,
        **kwargs,
    ) -> list[_CC]: ...
    @overload
    def search(
        self,
        *,
        comp_class: type[_CC],
        todo: bool | None = ...,
        include_completed: bool = ...,
        sort_keys: Sequence[str] = ...,
        **kwargs,
    ) -> list[_CC]: ...
    def build_search_xml_query(
        self,
        comp_class: _CompClass | None = ...,
        todo: bool | None = ...,
        ignore_completed1: bool | None = ...,
        ignore_completed2: bool | None = ...,
        ignore_completed3: bool | None = ...,
        event: bool | None = ...,
        category: Incomplete | None = ...,
        class_: Incomplete | None = ...,
        filters: list[Incomplete] | None = ...,
        expand: bool | None = ...,
        start: datetime.datetime | None = ...,
        end: datetime.datetime | None = ...,
        *,
        uid=...,
        summary=...,
        comment=...,
        description=...,
        location=...,
        status=...,
    ) -> tuple[CalendarQuery, _CompClass]: ...
    def freebusy_request(self, start: datetime.datetime, end: datetime.datetime) -> FreeBusy: ...
    def todos(self, sort_keys: Iterable[str] = ..., include_completed: bool = ..., sort_key: str | None = ...) -> list[Todo]: ...
    def event_by_url(self, href, data: Any | None = ...) -> Event: ...
    def object_by_uid(self, uid: str, comp_filter: CompFilter | None = ..., comp_class: _CompClass | None = ...) -> Event: ...
    def todo_by_uid(self, uid: str) -> CalendarObjectResource: ...
    def event_by_uid(self, uid: str) -> CalendarObjectResource: ...
    def journal_by_uid(self, uid: str) -> CalendarObjectResource: ...
    event = event_by_uid
    def events(self) -> list[Event]: ...
    def objects_by_sync_token(
        self, sync_token: Any | None = ..., load_objects: bool = ...
    ) -> SynchronizableCalendarObjectCollection: ...
    objects = objects_by_sync_token
    def journals(self) -> list[Journal]: ...

class ScheduleMailbox(Calendar):
    def __init__(
        self,
        client: DAVClient | None = ...,
        principal: Principal | None = ...,
        url: str | ParseResult | SplitResult | URL | None = ...,
    ) -> None: ...
    def get_items(self): ...

class ScheduleInbox(ScheduleMailbox):
    findprop = ScheduleInboxURL

class ScheduleOutbox(ScheduleMailbox):
    findprop = ScheduleOutboxURL

class SynchronizableCalendarObjectCollection:
    def __init__(self, calendar, objects, sync_token) -> None: ...
    def __iter__(self) -> Iterator[Any]: ...
    def objects_by_url(self): ...
    def sync(self) -> tuple[Any, Any]: ...

class CalendarObjectResource(DAVObject):
    def __init__(
        self,
        client: DAVClient | None = ...,
        url: str | ParseResult | SplitResult | URL | None = ...,
        data: Any | None = ...,
        parent: Any | None = ...,
        id: Any | None = ...,
        props: Any | None = ...,
    ) -> None: ...
    def add_organizer(self) -> None: ...
    def add_attendee(self, attendee, no_default_parameters: bool = ..., **parameters) -> None: ...
    def is_invite_request(self) -> bool: ...
    def accept_invite(self, calendar: Any | None = ...) -> None: ...
    def decline_invite(self, calendar: Any | None = ...) -> None: ...
    def tentatively_accept_invite(self, calendar: Any | None = ...) -> None: ...
    def copy(self: Self, keep_uid: bool = ..., new_parent: Any | None = ...) -> Self: ...
    def load(self: Self) -> Self: ...
    def change_attendee_status(self, attendee: Any | None = ..., **kwargs) -> None: ...
    def save(
        self: Self,
        no_overwrite: bool = ...,
        no_create: bool = ...,
        obj_type: str | None = ...,
        increase_seqno: bool = ...,
        if_schedule_tag_match: bool = ...,
    ) -> Self: ...
    data: Any
    vobject_instance: VBase
    icalendar_instance: Any
    instance: VBase

class Event(CalendarObjectResource): ...
class Journal(CalendarObjectResource): ...

class FreeBusy(CalendarObjectResource):
    def __init__(self, parent, data, url: str | ParseResult | SplitResult | URL | None = ..., id: Any | None = ...) -> None: ...

class Todo(CalendarObjectResource):
    def complete(
        self,
        completion_timestamp: datetime.datetime | None = ...,
        handle_rrule: bool = ...,
        rrule_mode: Literal["safe", "this_and_future"] = ...,
    ) -> None: ...



from typing import Any

class EntryState:
    dn: Any
    status: Any
    attributes: Any
    raw_attributes: Any
    response: Any
    cursor: Any
    origin: Any
    read_time: Any
    changes: Any
    definition: Any
    def __init__(self, dn, cursor) -> None: ...
    def set_status(self, status) -> None: ...
    @property
    def entry_raw_attributes(self): ...

class EntryBase:
    def __init__(self, dn, cursor) -> None: ...
    def __iter__(self): ...
    def __contains__(self, item): ...
    def __getattr__(self, item): ...
    def __setattr__(self, item, value) -> None: ...
    def __getitem__(self, item): ...
    def __eq__(self, other): ...
    def __lt__(self, other): ...
    @property
    def entry_dn(self): ...
    @property
    def entry_cursor(self): ...
    @property
    def entry_status(self): ...
    @property
    def entry_definition(self): ...
    @property
    def entry_raw_attributes(self): ...
    def entry_raw_attribute(self, name): ...
    @property
    def entry_mandatory_attributes(self): ...
    @property
    def entry_attributes(self): ...
    @property
    def entry_attributes_as_dict(self): ...
    @property
    def entry_read_time(self): ...
    def entry_to_json(
        self,
        raw: bool = ...,
        indent: int = ...,
        sort: bool = ...,
        stream: Any | None = ...,
        checked_attributes: bool = ...,
        include_empty: bool = ...,
    ): ...
    def entry_to_ldif(
        self, all_base64: bool = ..., line_separator: Any | None = ..., sort_order: Any | None = ..., stream: Any | None = ...
    ): ...

class Entry(EntryBase):
    def entry_writable(
        self,
        object_def: Any | None = ...,
        writer_cursor: Any | None = ...,
        attributes: Any | None = ...,
        custom_validator: Any | None = ...,
        auxiliary_class: Any | None = ...,
    ): ...

class WritableEntry(EntryBase):
    def __setitem__(self, key, value) -> None: ...
    def __setattr__(self, item, value) -> None: ...
    def __getattr__(self, item): ...
    @property
    def entry_virtual_attributes(self): ...
    def entry_commit_changes(self, refresh: bool = ..., controls: Any | None = ..., clear_history: bool = ...): ...
    def entry_discard_changes(self) -> None: ...
    def entry_delete(self) -> None: ...
    def entry_refresh(self, tries: int = ..., seconds: int = ...): ...
    def entry_move(self, destination_dn) -> None: ...
    def entry_rename(self, new_name) -> None: ...
    @property
    def entry_changes(self): ...



# This only exists in 3.11+. See VERSIONS.

from _typeshed import Self
from collections.abc import Coroutine, Generator
from contextvars import Context
from types import TracebackType
from typing import Any, TypeVar

from .tasks import Task

__all__ = ["TaskGroup"]

_T = TypeVar("_T")

class TaskGroup:
    async def __aenter__(self: Self) -> Self: ...
    async def __aexit__(self, et: type[BaseException] | None, exc: BaseException | None, tb: TracebackType | None) -> None: ...
    def create_task(
        self, coro: Generator[Any, None, _T] | Coroutine[Any, Any, _T], *, name: str | None = ..., context: Context | None = ...
    ) -> Task[_T]: ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class ExternalCell(Serialisable):  # type: ignore[misc]
    r: Any
    t: Any
    vm: Any
    v: Any
    def __init__(self, r: Any | None = ..., t: Any | None = ..., vm: Any | None = ..., v: Any | None = ...) -> None: ...

class ExternalRow(Serialisable):  # type: ignore[misc]
    r: Any
    cell: Any
    __elements__: Any
    def __init__(self, r=..., cell: Any | None = ...) -> None: ...

class ExternalSheetData(Serialisable):  # type: ignore[misc]
    sheetId: Any
    refreshError: Any
    row: Any
    __elements__: Any
    def __init__(self, sheetId: Any | None = ..., refreshError: Any | None = ..., row=...) -> None: ...

class ExternalSheetDataSet(Serialisable):  # type: ignore[misc]
    sheetData: Any
    __elements__: Any
    def __init__(self, sheetData: Any | None = ...) -> None: ...

class ExternalSheetNames(Serialisable):  # type: ignore[misc]
    sheetName: Any
    __elements__: Any
    def __init__(self, sheetName=...) -> None: ...

class ExternalDefinedName(Serialisable):
    tagname: str
    name: Any
    refersTo: Any
    sheetId: Any
    def __init__(self, name: Any | None = ..., refersTo: Any | None = ..., sheetId: Any | None = ...) -> None: ...

class ExternalBook(Serialisable):
    tagname: str
    sheetNames: Any
    definedNames: Any
    sheetDataSet: Any
    id: Any
    __elements__: Any
    def __init__(
        self, sheetNames: Any | None = ..., definedNames=..., sheetDataSet: Any | None = ..., id: Any | None = ...
    ) -> None: ...

class ExternalLink(Serialisable):
    tagname: str
    mime_type: str
    externalBook: Any
    file_link: Any
    __elements__: Any
    def __init__(
        self, externalBook: Any | None = ..., ddeLink: Any | None = ..., oleLink: Any | None = ..., extLst: Any | None = ...
    ) -> None: ...
    def to_tree(self): ...
    @property
    def path(self): ...

def read_external_link(archive, book_path): ...



from _typeshed import Incomplete
from asyncio import AbstractEventLoop
from collections.abc import Generator, Iterable
from tempfile import TemporaryDirectory, _BytesMode
from types import coroutine as coroutine
from typing import TypeVar

from ..base import AsyncBase as AsyncBase
from ..threadpool.utils import (
    cond_delegate_to_executor as cond_delegate_to_executor,
    delegate_to_executor as delegate_to_executor,
    proxy_property_directly as proxy_property_directly,
)

_T = TypeVar("_T")

class AsyncSpooledTemporaryFile(AsyncBase[_T]):
    def fileno(self) -> Generator[Incomplete, Incomplete, Incomplete]: ...
    def rollover(self) -> Generator[Incomplete, Incomplete, Incomplete]: ...
    async def flush(self) -> None: ...
    async def isatty(self) -> bool: ...
    # All must return `AnyStr`:
    async def read(self, __n: int = ...) -> Incomplete: ...
    async def readline(self, __limit: int | None = ...) -> Incomplete: ...
    async def readlines(self, __hint: int = ...) -> list[Incomplete]: ...
    # ---
    async def seek(self, offset: int, whence: int = ...) -> int: ...
    async def tell(self) -> int: ...
    async def truncate(self, size: int | None = ...) -> None: ...
    @property
    def closed(self) -> bool: ...
    @property
    def encoding(self) -> str: ...
    @property
    def mode(self) -> _BytesMode: ...
    @property
    def name(self) -> str: ...
    @property
    def newlines(self) -> str: ...
    # Both should work with `AnyStr`, like in `tempfile`:
    async def write(self, s: Incomplete) -> int: ...
    async def writelines(self, iterable: Iterable[Incomplete]) -> None: ...

class AsyncTemporaryDirectory:
    async def cleanup(self) -> None: ...
    @property
    def name(self) -> Incomplete: ...  # should be `AnyStr`
    def __init__(
        self, file: TemporaryDirectory[Incomplete], loop: AbstractEventLoop | None, executor: Incomplete | None
    ) -> None: ...
    async def close(self) -> None: ...



import sys
from ctypes import _CArgObject, _PointerLike
from typing_extensions import TypeAlias

FUNCFLAG_CDECL: int
FUNCFLAG_PYTHONAPI: int
FUNCFLAG_USE_ERRNO: int
FUNCFLAG_USE_LASTERROR: int
RTLD_GLOBAL: int
RTLD_LOCAL: int

if sys.version_info >= (3, 11):
    CTYPES_MAX_ARGCOUNT: int

if sys.platform == "win32":
    # Description, Source, HelpFile, HelpContext, scode
    _COMError_Details: TypeAlias = tuple[str | None, str | None, str | None, int | None, int | None]

    class COMError(Exception):
        hresult: int
        text: str | None
        details: _COMError_Details

        def __init__(self, hresult: int, text: str | None, details: _COMError_Details) -> None: ...

    def CopyComPointer(src: _PointerLike, dst: _PointerLike | _CArgObject) -> int: ...

    FUNCFLAG_HRESULT: int
    FUNCFLAG_STDCALL: int



from collections.abc import Iterable
from typing import Any, Protocol, Union
from typing_extensions import TypeAlias

from .Image import Image, Resampling, _Resample, _Size
from .ImageColor import _Ink

_Border: TypeAlias = Union[int, tuple[int, int], tuple[int, int, int, int]]

class _Deformer(Protocol):
    def getmesh(self, image: Image): ...

def autocontrast(
    image: Image, cutoff: int = ..., ignore: int | None = ..., mask: Image | None = ..., preserve_tone: bool = ...
) -> Image: ...
def colorize(
    image: Image,
    black: int | str,
    white: int | str,
    mid: int | str | None = ...,
    blackpoint: int = ...,
    whitepoint: int = ...,
    midpoint: int = ...,
) -> Image: ...
def contain(image: Image, size: _Size, method: Resampling | _Resample = ...) -> Image: ...
def pad(
    image: Image, size: _Size, method: Resampling | _Resample = ..., color: Any | None = ..., centering: Iterable[float] = ...
) -> Image: ...
def crop(image: Image, border: _Border = ...) -> Image: ...
def scale(image: Image, factor: float, resample: Resampling | _Resample = ...) -> Image: ...
def deform(image: Image, deformer: _Deformer, resample: Resampling | _Resample = ...) -> Image: ...
def equalize(image: Image, mask: Any | None = ...) -> Image: ...
def expand(image: Image, border: _Border = ..., fill: _Ink = ...) -> Image: ...
def fit(
    image: Image, size: _Size, method: Resampling | _Resample = ..., bleed: float = ..., centering: Iterable[float] = ...
) -> Image: ...
def flip(image: Image) -> Image: ...
def grayscale(image: Image) -> Image: ...
def invert(image: Image) -> Image: ...
def mirror(image: Image) -> Image: ...
def posterize(image: Image, bits: int) -> Image: ...
def solarize(image: Image, threshold: int = ...) -> Image: ...
def exif_transpose(image: Image) -> Image: ...



from collections.abc import Callable
from typing import Any

GROUP_NAME: str
DEFAULT_KEYWORDS: Any
DEFAULT_MAPPING: Any
empty_msgid_warning: str

def extract_from_dir(
    dirname: Any | None = ...,
    method_map=...,
    options_map: Any | None = ...,
    keywords=...,
    comment_tags=...,
    callback: Any | None = ...,
    strip_comment_tags: bool = ...,
    directory_filter: Callable[[str], bool] | None = ...,
) -> None: ...
def check_and_call_extract_file(
    filepath, method_map, options_map, callback, keywords, comment_tags, strip_comment_tags, dirpath: Any | None = ...
) -> None: ...
def extract_from_file(
    method, filename, keywords=..., comment_tags=..., options: Any | None = ..., strip_comment_tags: bool = ...
): ...
def extract(
    method, fileobj, keywords=..., comment_tags=..., options: Any | None = ..., strip_comment_tags: bool = ...
) -> None: ...
def extract_nothing(fileobj, keywords, comment_tags, options): ...
def extract_python(fileobj, keywords, comment_tags, options): ...
def extract_javascript(fileobj, keywords, comment_tags, options) -> None: ...



from collections.abc import Container, Iterable, Mapping, MutableMapping
from typing import Any

from .backends.base import Key

def encode(
    claims: MutableMapping[str, Any],
    # Internally it calls jws.sign() that expects a key dict instance instead of Mapping
    key: str | bytes | dict[str, Any] | Key,
    algorithm: str = ...,
    headers: Mapping[str, Any] | None = ...,
    access_token: str | None = ...,
) -> str: ...
def decode(
    token: str | bytes,
    key: str | bytes | Mapping[str, Any] | Key,
    algorithms: str | Container[str] | None = ...,
    options: Mapping[str, Any] | None = ...,
    audience: str | None = ...,
    issuer: str | Iterable[str] | None = ...,
    subject: str | None = ...,
    access_token: str | None = ...,
) -> dict[str, Any]: ...
def get_unverified_header(token: str) -> dict[str, Any]: ...
def get_unverified_headers(token: str) -> dict[str, Any]: ...
def get_unverified_claims(token: str) -> dict[str, Any]: ...



from re import Match
from typing import Any

class JSONDecoder:
    def __init__(self, **kwargs: Any) -> None: ...
    def decode(self, s: str, _w: Match[str], _PY3: bool) -> Any: ...
    def raw_decode(self, s: str, idx: int, _w: Match[str], _PY3: bool) -> tuple[Any, int]: ...



from .authorization_code import AuthorizationCodeGrant as AuthorizationCodeGrant
from .base import GrantTypeBase as GrantTypeBase
from .dispatchers import (
    AuthorizationCodeGrantDispatcher as AuthorizationCodeGrantDispatcher,
    AuthorizationTokenGrantDispatcher as AuthorizationTokenGrantDispatcher,
    ImplicitTokenGrantDispatcher as ImplicitTokenGrantDispatcher,
)
from .hybrid import HybridGrant as HybridGrant
from .implicit import ImplicitGrant as ImplicitGrant



from typing import Any

import sqlalchemy.types as sqltypes

class RangeOperators:
    class comparator_factory(sqltypes.Concatenable.Comparator[Any]):
        def __ne__(self, other): ...
        def contains(self, other, **kw): ...
        def contained_by(self, other): ...
        def overlaps(self, other): ...
        def strictly_left_of(self, other): ...
        __lshift__: Any
        def strictly_right_of(self, other): ...
        __rshift__: Any
        def not_extend_right_of(self, other): ...
        def not_extend_left_of(self, other): ...
        def adjacent_to(self, other): ...
        def __add__(self, other): ...

class INT4RANGE(RangeOperators, sqltypes.TypeEngine):
    __visit_name__: str

class INT8RANGE(RangeOperators, sqltypes.TypeEngine):
    __visit_name__: str

class NUMRANGE(RangeOperators, sqltypes.TypeEngine):
    __visit_name__: str

class DATERANGE(RangeOperators, sqltypes.TypeEngine):
    __visit_name__: str

class TSRANGE(RangeOperators, sqltypes.TypeEngine):
    __visit_name__: str

class TSTZRANGE(RangeOperators, sqltypes.TypeEngine):
    __visit_name__: str



import asyncio
from typing import Any, Awaitable, List, Tuple, Union
from typing_extensions import assert_type


async def coro1() -> int:
    return 42


async def coro2() -> str:
    return "spam"


async def test_gather(awaitable1: Awaitable[int], awaitable2: Awaitable[str]) -> None:
    a = await asyncio.gather(awaitable1)
    assert_type(a, Tuple[int])

    b = await asyncio.gather(awaitable1, awaitable2, return_exceptions=True)
    assert_type(b, Tuple[Union[int, BaseException], Union[str, BaseException]])

    c = await asyncio.gather(awaitable1, awaitable2, awaitable1, awaitable1, awaitable1, awaitable1)
    assert_type(c, List[Any])

    awaitables_list: List[Awaitable[int]] = [awaitable1]
    d = await asyncio.gather(*awaitables_list)
    assert_type(d, List[Any])

    e = await asyncio.gather()
    assert_type(e, List[Any])


asyncio.run(test_gather(coro1(), coro2()))



from _typeshed import Self, StrOrBytesPath
from codecs import StreamReaderWriter
from collections.abc import Generator, Iterator
from types import TracebackType
from typing_extensions import Literal

PY3: Literal[True]
MATCHER: str

class LogReader:
    filename: StrOrBytesPath
    mass: int
    size: int
    read: int
    pipe: StreamReaderWriter | None
    def __init__(self, filename: StrOrBytesPath, mass: int = ...) -> None: ...
    def __enter__(self: Self) -> Self: ...
    def __exit__(
        self, error_type: type[BaseException] | None, value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...
    def __iter__(self) -> Iterator[str]: ...
    def readlines(self, until: int = ...) -> Generator[tuple[int, str], None, None]: ...

class CronLog(LogReader):
    user: str | None
    def __init__(self, filename: StrOrBytesPath = ..., user: str | None = ...) -> None: ...
    def for_program(self, command: str) -> ProgramLog: ...
    def __iter__(self) -> dict[str, str | None]: ...  # type: ignore[override]

class ProgramLog:
    log: CronLog
    command: str
    def __init__(self, log: CronLog, command: str) -> None: ...
    def __iter__(self) -> dict[str, str | None]: ...



from consolemenu.console_menu import ConsoleMenu
from consolemenu.items import ExternalItem as ExternalItem

class CommandItem(ExternalItem):
    command: str
    arguments: list[str]
    exit_status: int | None
    def __init__(
        self, text: str, command: str, arguments: list[str] | None = ..., menu: ConsoleMenu | None = ..., should_exit: bool = ...
    ) -> None: ...
    def action(self) -> None: ...
    def get_return(self) -> int: ...



from typing import Any

from openpyxl.descriptors import Typed
from openpyxl.descriptors.serialisable import Serialisable

class Title(Serialisable):
    tagname: str
    tx: Any
    text: Any
    layout: Any
    overlay: Any
    spPr: Any
    graphicalProperties: Any
    txPr: Any
    body: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        tx: Any | None = ...,
        layout: Any | None = ...,
        overlay: Any | None = ...,
        spPr: Any | None = ...,
        txPr: Any | None = ...,
        extLst: Any | None = ...,
    ) -> None: ...

def title_maker(text): ...

class TitleDescriptor(Typed):
    expected_type: Any
    allow_none: bool
    def __set__(self, instance, value) -> None: ...



from typing import Any

from openpyxl.descriptors import Typed
from openpyxl.descriptors.serialisable import Serialisable

COLOR_INDEX: Any
BLACK: Any
WHITE: Any
BLUE: Any
aRGB_REGEX: Any

class RGB(Typed):
    expected_type: Any
    def __set__(self, instance, value) -> None: ...

class Color(Serialisable):
    tagname: str
    rgb: Any
    indexed: Any
    auto: Any
    theme: Any
    tint: Any
    type: Any
    def __init__(
        self,
        rgb=...,
        indexed: Any | None = ...,
        auto: Any | None = ...,
        theme: Any | None = ...,
        tint: float = ...,
        index: Any | None = ...,
        type: str = ...,
    ) -> None: ...
    @property
    def value(self): ...
    @value.setter
    def value(self, value) -> None: ...
    def __iter__(self): ...
    @property
    def index(self): ...
    def __add__(self, other): ...

class ColorDescriptor(Typed):
    expected_type: Any
    def __set__(self, instance, value) -> None: ...

class RgbColor(Serialisable):
    tagname: str
    rgb: Any
    def __init__(self, rgb: Any | None = ...) -> None: ...

class ColorList(Serialisable):
    tagname: str
    indexedColors: Any
    mruColors: Any
    __elements__: Any
    def __init__(self, indexedColors=..., mruColors=...) -> None: ...
    def __bool__(self): ...
    @property
    def index(self): ...



from re import Pattern

from dateparser.conf import Settings

DIGIT_GROUP_PATTERN: Pattern[str]
NUMERAL_PATTERN: Pattern[str]

class Locale:
    shortname: str
    def __init__(self, shortname: str, language_info) -> None: ...
    def is_applicable(self, date_string: str, strip_timezone: bool = ..., settings: Settings | None = ...) -> bool: ...
    def count_applicability(self, text: str, strip_timezone: bool = ..., settings: Settings | None = ...): ...
    @staticmethod
    def clean_dictionary(dictionary, threshold: int = ...): ...
    def translate(self, date_string: str, keep_formatting: bool = ..., settings: Settings | None = ...) -> str: ...
    def translate_search(self, search_string, settings: Settings | None = ...): ...
    def get_wordchars_for_detection(self, settings): ...
    def to_parserinfo(self, base_cls=...): ...



#!/usr/bin/env python3
"""Run mypy on the "tests" and "scripts" directories."""
from __future__ import annotations

import argparse
import subprocess
import sys
from itertools import product
from typing_extensions import TypeAlias

from utils import colored, print_error

ReturnCode: TypeAlias = int

SUPPORTED_PLATFORMS = ("linux", "darwin", "win32")
SUPPORTED_VERSIONS = ("3.11", "3.10", "3.9")
DIRECTORIES_TO_TEST = ("scripts", "tests")

parser = argparse.ArgumentParser(description="Run mypy on typeshed's own code in the `scripts` and `tests` directories.")
parser.add_argument(
    "dir",
    choices=DIRECTORIES_TO_TEST + ([],),
    nargs="*",
    action="extend",
    help=f"Test only these top-level typeshed directories (defaults to {DIRECTORIES_TO_TEST!r})",
)
parser.add_argument(
    "--platform",
    choices=SUPPORTED_PLATFORMS,
    nargs="*",
    action="extend",
    help="Run mypy for certain OS platforms (defaults to sys.platform)",
)
parser.add_argument(
    "-p",
    "--python-version",
    choices=SUPPORTED_VERSIONS,
    nargs="*",
    action="extend",
    help="Run mypy for certain Python versions (defaults to sys.version_info[:2])",
)


def run_mypy_as_subprocess(directory: str, platform: str, version: str) -> ReturnCode:
    command = [
        sys.executable,
        "-m",
        "mypy",
        directory,
        "--platform",
        platform,
        "--python-version",
        version,
        "--strict",
        "--show-traceback",
        "--show-error-codes",
        "--no-error-summary",
        "--enable-error-code",
        "ignore-without-code",
        "--namespace-packages",
    ]
    if directory == "tests" and platform == "win32":
        command.extend(["--exclude", "tests/pytype_test.py"])
    result = subprocess.run(command, capture_output=True)
    stdout, stderr = result.stdout, result.stderr
    if stderr:
        print_error(stderr.decode())
    if stdout:
        print_error(stdout.decode())
    return result.returncode


def main() -> ReturnCode:
    args = parser.parse_args()
    directories = args.dir or DIRECTORIES_TO_TEST
    platforms = args.platform or [sys.platform]
    versions = args.python_version or [f"3.{sys.version_info[1]}"]

    code = 0

    for directory, platform, version in product(directories, platforms, versions):
        print(f'Running "mypy --platform {platform} --python-version {version}" on the "{directory}" directory...')
        code = max(code, run_mypy_as_subprocess(directory, platform, version))

    if code:
        print_error("Test completed with errors")
    else:
        print(colored("Test completed successfully!", "green"))
    return code


if __name__ == "__main__":
    try:
        code = main()
    except KeyboardInterrupt:
        print_error("\n\n!!!\nTest aborted due to KeyboardInterrupt\n!!!")
        code = 1
    raise SystemExit(code)



from typing import Any

reContainer: Any

def is_container(node): ...

class NodeWalker:
    current: Any
    root: Any
    entering: bool
    def __init__(self, root) -> None: ...
    def __next__(self): ...
    next: Any
    def __iter__(self): ...
    def nxt(self): ...
    def resume_at(self, node, entering) -> None: ...

class Node:
    t: Any
    parent: Any
    first_child: Any
    last_child: Any
    prv: Any
    nxt: Any
    sourcepos: Any
    last_line_blank: bool
    last_line_checked: bool
    is_open: bool
    string_content: str
    literal: Any
    list_data: Any
    info: Any
    destination: Any
    title: Any
    is_fenced: bool
    fence_char: Any
    fence_length: int
    fence_offset: Any
    level: Any
    on_enter: Any
    on_exit: Any
    def __init__(self, node_type, sourcepos) -> None: ...
    def pretty(self) -> None: ...
    def normalize(self) -> None: ...
    def is_container(self): ...
    def append_child(self, child) -> None: ...
    def prepend_child(self, child) -> None: ...
    def unlink(self) -> None: ...
    def insert_after(self, sibling) -> None: ...
    def insert_before(self, sibling) -> None: ...
    def walker(self): ...



from typing import Any

INVALID_TITLE_REGEX: Any

def avoid_duplicate_name(names, value): ...

class _WorkbookChild:
    HeaderFooter: Any
    def __init__(self, parent: Any | None = ..., title: Any | None = ...) -> None: ...
    @property
    def parent(self): ...
    @property
    def encoding(self): ...
    @property
    def title(self): ...
    @title.setter
    def title(self, value) -> None: ...
    @property
    def oddHeader(self): ...
    @oddHeader.setter
    def oddHeader(self, value) -> None: ...
    @property
    def oddFooter(self): ...
    @oddFooter.setter
    def oddFooter(self, value) -> None: ...
    @property
    def evenHeader(self): ...
    @evenHeader.setter
    def evenHeader(self, value) -> None: ...
    @property
    def evenFooter(self): ...
    @evenFooter.setter
    def evenFooter(self, value) -> None: ...
    @property
    def firstHeader(self): ...
    @firstHeader.setter
    def firstHeader(self, value) -> None: ...
    @property
    def firstFooter(self): ...
    @firstFooter.setter
    def firstFooter(self, value) -> None: ...
    @property
    def path(self): ...



from typing import Any

from .base import BaseEndpoint as BaseEndpoint

class AuthorizationEndpoint(BaseEndpoint):
    def create_verifier(self, request, credentials): ...
    def create_authorization_response(
        self,
        uri,
        http_method: str = ...,
        body: Any | None = ...,
        headers: Any | None = ...,
        realms: Any | None = ...,
        credentials: Any | None = ...,
    ): ...
    def get_realms_and_credentials(self, uri, http_method: str = ..., body: Any | None = ..., headers: Any | None = ...): ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.workbook.child import _WorkbookChild

class Chartsheet(_WorkbookChild, Serialisable):
    tagname: str
    mime_type: str
    sheetPr: Any
    sheetViews: Any
    sheetProtection: Any
    customSheetViews: Any
    pageMargins: Any
    pageSetup: Any
    drawing: Any
    drawingHF: Any
    picture: Any
    webPublishItems: Any
    extLst: Any
    sheet_state: Any
    headerFooter: Any
    HeaderFooter: Any
    __elements__: Any
    __attrs__: Any
    def __init__(
        self,
        sheetPr: Any | None = ...,
        sheetViews: Any | None = ...,
        sheetProtection: Any | None = ...,
        customSheetViews: Any | None = ...,
        pageMargins: Any | None = ...,
        pageSetup: Any | None = ...,
        headerFooter: Any | None = ...,
        drawing: Any | None = ...,
        drawingHF: Any | None = ...,
        picture: Any | None = ...,
        webPublishItems: Any | None = ...,
        extLst: Any | None = ...,
        parent: Any | None = ...,
        title: str = ...,
        sheet_state: str = ...,
    ) -> None: ...
    def add_chart(self, chart) -> None: ...
    def to_tree(self): ...



from _typeshed import Self
from typing import Any

class Key:
    # Enable when we can use stubs from installed dependencies,
    # as `key` can be of type cryptography.x509.base.Certificate:
    # from cryptography.x509 import Certificate
    def __init__(self, key, algorithm) -> None: ...
    def sign(self, msg: bytes) -> bytes: ...
    def verify(self, msg: bytes, sig: bytes) -> bool: ...
    def public_key(self: Self) -> Self: ...
    def to_pem(self) -> bytes: ...
    def to_dict(self) -> dict[str, Any]: ...
    def encrypt(self, plain_text: str | bytes, aad: bytes | None = ...) -> tuple[bytes, bytes, bytes | None]: ...
    def decrypt(
        self, cipher_text: str | bytes, iv: str | bytes | None = ..., aad: bytes | None = ..., tag: bytes | None = ...
    ) -> bytes: ...
    def wrap_key(self, key_data: bytes) -> bytes: ...
    def unwrap_key(self, wrapped_key: bytes) -> bytes: ...

class DIRKey(Key):
    def __init__(self, key_data: str | bytes, algorithm: str) -> None: ...
    def to_dict(self) -> dict[str, Any]: ...



from _typeshed import Incomplete

def spawn(
    cmd: list[str], search_path: bool = ..., verbose: bool = ..., dry_run: bool = ..., env: Incomplete | None = ...
) -> None: ...
def find_executable(executable: str, path: str | None = ...) -> str | None: ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class ControlProperty(Serialisable):
    tagname: str
    anchor: Any
    locked: Any
    defaultSize: Any
    disabled: Any
    recalcAlways: Any
    uiObject: Any
    autoFill: Any
    autoLine: Any
    autoPict: Any
    macro: Any
    altText: Any
    linkedCell: Any
    listFillRange: Any
    cf: Any
    id: Any
    __elements__: Any
    def __init__(
        self,
        anchor: Any | None = ...,
        locked: bool = ...,
        defaultSize: bool = ...,
        _print: bool = ...,
        disabled: bool = ...,
        recalcAlways: bool = ...,
        uiObject: bool = ...,
        autoFill: bool = ...,
        autoLine: bool = ...,
        autoPict: bool = ...,
        macro: Any | None = ...,
        altText: Any | None = ...,
        linkedCell: Any | None = ...,
        listFillRange: Any | None = ...,
        cf: str = ...,
        id: Any | None = ...,
    ) -> None: ...

class Control(Serialisable):
    tagname: str
    controlPr: Any
    shapeId: Any
    name: Any
    __elements__: Any
    def __init__(self, controlPr: Any | None = ..., shapeId: Any | None = ..., name: Any | None = ...) -> None: ...

class Controls(Serialisable):
    tagname: str
    control: Any
    __elements__: Any
    def __init__(self, control=...) -> None: ...



from collections.abc import Generator
from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

RESERVED: Any
RESERVED_REGEX: Any
COL_RANGE: str
COL_RANGE_RE: Any
ROW_RANGE: str
ROW_RANGE_RE: Any
TITLES_REGEX: Any

class DefinedName(Serialisable):
    tagname: str
    name: Any
    comment: Any
    customMenu: Any
    description: Any
    help: Any
    statusBar: Any
    localSheetId: Any
    hidden: Any
    function: Any
    vbProcedure: Any
    xlm: Any
    functionGroupId: Any
    shortcutKey: Any
    publishToServer: Any
    workbookParameter: Any
    attr_text: Any
    value: Any
    def __init__(
        self,
        name: Any | None = ...,
        comment: Any | None = ...,
        customMenu: Any | None = ...,
        description: Any | None = ...,
        help: Any | None = ...,
        statusBar: Any | None = ...,
        localSheetId: Any | None = ...,
        hidden: Any | None = ...,
        function: Any | None = ...,
        vbProcedure: Any | None = ...,
        xlm: Any | None = ...,
        functionGroupId: Any | None = ...,
        shortcutKey: Any | None = ...,
        publishToServer: Any | None = ...,
        workbookParameter: Any | None = ...,
        attr_text: Any | None = ...,
    ) -> None: ...
    @property
    def type(self): ...
    @property
    def destinations(self) -> Generator[Any, None, None]: ...
    @property
    def is_reserved(self): ...
    @property
    def is_external(self): ...
    def __iter__(self): ...

class DefinedNameList(Serialisable):
    tagname: str
    definedName: Any
    def __init__(self, definedName=...) -> None: ...
    def append(self, defn) -> None: ...
    def __len__(self): ...
    def __contains__(self, name): ...
    def __getitem__(self, name): ...
    def get(self, name, scope: Any | None = ...): ...
    def __delitem__(self, name) -> None: ...
    def delete(self, name, scope: Any | None = ...): ...
    def localnames(self, scope): ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class LineEndProperties(Serialisable):
    tagname: str
    namespace: Any
    type: Any
    w: Any
    len: Any
    def __init__(self, type: Any | None = ..., w: Any | None = ..., len: Any | None = ...) -> None: ...

class DashStop(Serialisable):
    tagname: str
    namespace: Any
    d: Any
    length: Any
    sp: Any
    space: Any
    def __init__(self, d: int = ..., sp: int = ...) -> None: ...

class DashStopList(Serialisable):
    ds: Any
    def __init__(self, ds: Any | None = ...) -> None: ...

class LineProperties(Serialisable):
    tagname: str
    namespace: Any
    w: Any
    width: Any
    cap: Any
    cmpd: Any
    algn: Any
    noFill: Any
    solidFill: Any
    gradFill: Any
    pattFill: Any
    prstDash: Any
    dashStyle: Any
    custDash: Any
    round: Any
    bevel: Any
    miter: Any
    headEnd: Any
    tailEnd: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        w: Any | None = ...,
        cap: Any | None = ...,
        cmpd: Any | None = ...,
        algn: Any | None = ...,
        noFill: Any | None = ...,
        solidFill: Any | None = ...,
        gradFill: Any | None = ...,
        pattFill: Any | None = ...,
        prstDash: Any | None = ...,
        custDash: Any | None = ...,
        round: Any | None = ...,
        bevel: Any | None = ...,
        miter: Any | None = ...,
        headEnd: Any | None = ...,
        tailEnd: Any | None = ...,
        extLst: Any | None = ...,
    ) -> None: ...



from typing import Any

from .base import MySQLCompiler, MySQLDialect, MySQLExecutionContext

mariadb_cpy_minimum_version: Any

class MySQLExecutionContext_mariadbconnector(MySQLExecutionContext):
    def create_server_side_cursor(self): ...
    def create_default_cursor(self): ...

class MySQLCompiler_mariadbconnector(MySQLCompiler): ...

class MySQLDialect_mariadbconnector(MySQLDialect):
    driver: str
    supports_statement_cache: bool
    supports_unicode_statements: bool
    encoding: str
    convert_unicode: bool
    supports_sane_rowcount: bool
    supports_sane_multi_rowcount: bool
    supports_native_decimal: bool
    default_paramstyle: str
    statement_compiler: Any
    supports_server_side_cursors: bool
    paramstyle: str
    def __init__(self, **kwargs) -> None: ...
    @classmethod
    def dbapi(cls): ...
    def is_disconnect(self, e, connection, cursor): ...
    def create_connect_args(self, url): ...
    def do_begin_twophase(self, connection, xid) -> None: ...
    def do_prepare_twophase(self, connection, xid) -> None: ...
    def do_rollback_twophase(self, connection, xid, is_prepared: bool = ..., recover: bool = ...) -> None: ...
    def do_commit_twophase(self, connection, xid, is_prepared: bool = ..., recover: bool = ...) -> None: ...

dialect = MySQLDialect_mariadbconnector



from collections.abc import Iterable, Sequence
from typing import Any, NamedTuple

from consolemenu.screen import Screen
from consolemenu.validators.base import BaseValidator

class InputResult(NamedTuple):
    input_string: str
    validation_result: bool

class PromptFormatter:
    @staticmethod
    def format_prompt(
        prompt: str | None = ...,
        default: str | None = ...,
        enable_quit: bool = ...,
        quit_string: str = ...,
        quit_message: str = ...,
    ) -> str: ...

class PromptUtils:
    def __init__(self, screen: Screen, prompt_formatter: PromptFormatter | None = ...) -> None: ...
    @property
    def screen(self) -> Screen: ...
    def clear(self) -> None: ...
    def confirm_answer(self, answer: str, message: str | None = ...) -> bool: ...
    def enter_to_continue(self, message: str | None = ...) -> None: ...
    def input(
        self,
        prompt: str | None = ...,
        default: str | None = ...,
        validators: Iterable[BaseValidator] | None = ...,
        enable_quit: bool = ...,
        quit_string: str = ...,
        quit_message: str = ...,
    ) -> InputResult: ...
    def input_password(self, message: str | None = ...) -> str: ...
    def printf(self, *args: Any) -> None: ...
    def println(self, *args: Any) -> None: ...
    def prompt_and_confirm_password(self, message: str) -> str: ...
    def prompt_for_bilateral_choice(self, prompt: str, option1: str, option2: str) -> str: ...
    def prompt_for_trilateral_choice(self, prompt: str, option1: str, option2: str, option3: str) -> str: ...
    def prompt_for_yes_or_no(self, prompt: str) -> bool: ...
    def prompt_for_numbered_choice(self, choices: Sequence[str], title: str | None = ..., prompt: str = ...) -> int: ...
    def validate_input(self, input_string: str, validators: BaseValidator) -> bool: ...

class UserQuit(Exception): ...



MV_FLAG: int
PT_UNSPECIFIED: int
PT_NULL: int
PT_I2: int
PT_LONG: int
PT_R4: int
PT_DOUBLE: int
PT_CURRENCY: int
PT_APPTIME: int
PT_ERROR: int
PT_BOOLEAN: int
PT_OBJECT: int
PT_I8: int
PT_STRING8: int
PT_UNICODE: int
PT_SYSTIME: int
PT_CLSID: int
PT_BINARY: int
PT_SHORT: int
PT_I4: int
PT_FLOAT: int
PT_R8: int
PT_LONGLONG: int
PT_MV_I2: int
PT_MV_LONG: int
PT_MV_R4: int
PT_MV_DOUBLE: int
PT_MV_CURRENCY: int
PT_MV_APPTIME: int
PT_MV_SYSTIME: int
PT_MV_STRING8: int
PT_MV_BINARY: int
PT_MV_UNICODE: int
PT_MV_CLSID: int
PT_MV_I8: int
PT_MV_SHORT: int
PT_MV_I4: int
PT_MV_FLOAT: int
PT_MV_R8: int
PT_MV_LONGLONG: int
PT_TSTRING: int
PT_MV_TSTRING: int
PROP_TYPE_MASK: int

def PROP_TYPE(ulPropTag: int) -> int: ...
def PROP_ID(ulPropTag: int) -> int: ...
def PROP_TAG(ulPropType: int, ulPropID: int) -> int: ...

PROP_ID_NULL: int
PROP_ID_INVALID: int
PR_NULL: int
PR_ACKNOWLEDGEMENT_MODE: int
PR_ALTERNATE_RECIPIENT_ALLOWED: int
PR_AUTHORIZING_USERS: int
PR_AUTO_FORWARD_COMMENT: int
PR_AUTO_FORWARD_COMMENT_W: int
PR_AUTO_FORWARD_COMMENT_A: int
PR_AUTO_FORWARDED: int
PR_CONTENT_CONFIDENTIALITY_ALGORITHM_ID: int
PR_CONTENT_CORRELATOR: int
PR_CONTENT_IDENTIFIER: int
PR_CONTENT_IDENTIFIER_W: int
PR_CONTENT_IDENTIFIER_A: int
PR_CONTENT_LENGTH: int
PR_CONTENT_RETURN_REQUESTED: int
PR_CONVERSATION_KEY: int
PR_CONVERSION_EITS: int
PR_CONVERSION_WITH_LOSS_PROHIBITED: int
PR_CONVERTED_EITS: int
PR_DEFERRED_DELIVERY_TIME: int
PR_DELIVER_TIME: int
PR_DISCARD_REASON: int
PR_DISCLOSURE_OF_RECIPIENTS: int
PR_DL_EXPANSION_HISTORY: int
PR_DL_EXPANSION_PROHIBITED: int
PR_EXPIRY_TIME: int
PR_IMPLICIT_CONVERSION_PROHIBITED: int
PR_IMPORTANCE: int
PR_IPM_ID: int
PR_LATEST_DELIVERY_TIME: int
PR_MESSAGE_CLASS: int
PR_MESSAGE_CLASS_W: int
PR_MESSAGE_CLASS_A: int
PR_MESSAGE_DELIVERY_ID: int
PR_MESSAGE_SECURITY_LABEL: int
PR_OBSOLETED_IPMS: int
PR_ORIGINALLY_INTENDED_RECIPIENT_NAME: int
PR_ORIGINAL_EITS: int
PR_ORIGINATOR_CERTIFICATE: int
PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED: int
PR_ORIGINATOR_RETURN_ADDRESS: int
PR_PARENT_KEY: int
PR_PRIORITY: int
PR_ORIGIN_CHECK: int
PR_PROOF_OF_SUBMISSION_REQUESTED: int
PR_READ_RECEIPT_REQUESTED: int
PR_RECEIPT_TIME: int
PR_RECIPIENT_REASSIGNMENT_PROHIBITED: int
PR_REDIRECTION_HISTORY: int
PR_RELATED_IPMS: int
PR_ORIGINAL_SENSITIVITY: int
PR_LANGUAGES: int
PR_LANGUAGES_W: int
PR_LANGUAGES_A: int
PR_REPLY_TIME: int
PR_REPORT_TAG: int
PR_REPORT_TIME: int
PR_RETURNED_IPM: int
PR_SECURITY: int
PR_INCOMPLETE_COPY: int
PR_SENSITIVITY: int
PR_SUBJECT: int
PR_SUBJECT_W: int
PR_SUBJECT_A: int
PR_SUBJECT_IPM: int
PR_CLIENT_SUBMIT_TIME: int
PR_REPORT_NAME: int
PR_REPORT_NAME_W: int
PR_REPORT_NAME_A: int
PR_SENT_REPRESENTING_SEARCH_KEY: int
PR_X400_CONTENT_TYPE: int
PR_SUBJECT_PREFIX: int
PR_SUBJECT_PREFIX_W: int
PR_SUBJECT_PREFIX_A: int
PR_NON_RECEIPT_REASON: int
PR_RECEIVED_BY_ENTRYID: int
PR_RECEIVED_BY_NAME: int
PR_RECEIVED_BY_NAME_W: int
PR_RECEIVED_BY_NAME_A: int
PR_SENT_REPRESENTING_ENTRYID: int
PR_SENT_REPRESENTING_NAME: int
PR_SENT_REPRESENTING_NAME_W: int
PR_SENT_REPRESENTING_NAME_A: int
PR_RCVD_REPRESENTING_ENTRYID: int
PR_RCVD_REPRESENTING_NAME: int
PR_RCVD_REPRESENTING_NAME_W: int
PR_RCVD_REPRESENTING_NAME_A: int
PR_REPORT_ENTRYID: int
PR_READ_RECEIPT_ENTRYID: int
PR_MESSAGE_SUBMISSION_ID: int
PR_PROVIDER_SUBMIT_TIME: int
PR_ORIGINAL_SUBJECT: int
PR_ORIGINAL_SUBJECT_W: int
PR_ORIGINAL_SUBJECT_A: int
PR_DISC_VAL: int
PR_ORIG_MESSAGE_CLASS: int
PR_ORIG_MESSAGE_CLASS_W: int
PR_ORIG_MESSAGE_CLASS_A: int
PR_ORIGINAL_AUTHOR_ENTRYID: int
PR_ORIGINAL_AUTHOR_NAME: int
PR_ORIGINAL_AUTHOR_NAME_W: int
PR_ORIGINAL_AUTHOR_NAME_A: int
PR_ORIGINAL_SUBMIT_TIME: int
PR_REPLY_RECIPIENT_ENTRIES: int
PR_REPLY_RECIPIENT_NAMES: int
PR_REPLY_RECIPIENT_NAMES_W: int
PR_REPLY_RECIPIENT_NAMES_A: int
PR_RECEIVED_BY_SEARCH_KEY: int
PR_RCVD_REPRESENTING_SEARCH_KEY: int
PR_READ_RECEIPT_SEARCH_KEY: int
PR_REPORT_SEARCH_KEY: int
PR_ORIGINAL_DELIVERY_TIME: int
PR_ORIGINAL_AUTHOR_SEARCH_KEY: int
PR_MESSAGE_TO_ME: int
PR_MESSAGE_CC_ME: int
PR_MESSAGE_RECIP_ME: int
PR_ORIGINAL_SENDER_NAME: int
PR_ORIGINAL_SENDER_NAME_W: int
PR_ORIGINAL_SENDER_NAME_A: int
PR_ORIGINAL_SENDER_ENTRYID: int
PR_ORIGINAL_SENDER_SEARCH_KEY: int
PR_ORIGINAL_SENT_REPRESENTING_NAME: int
PR_ORIGINAL_SENT_REPRESENTING_NAME_W: int
PR_ORIGINAL_SENT_REPRESENTING_NAME_A: int
PR_ORIGINAL_SENT_REPRESENTING_ENTRYID: int
PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY: int
PR_START_DATE: int
PR_END_DATE: int
PR_OWNER_APPT_ID: int
PR_RESPONSE_REQUESTED: int
PR_SENT_REPRESENTING_ADDRTYPE: int
PR_SENT_REPRESENTING_ADDRTYPE_W: int
PR_SENT_REPRESENTING_ADDRTYPE_A: int
PR_SENT_REPRESENTING_EMAIL_ADDRESS: int
PR_SENT_REPRESENTING_EMAIL_ADDRESS_W: int
PR_SENT_REPRESENTING_EMAIL_ADDRESS_A: int
PR_ORIGINAL_SENDER_ADDRTYPE: int
PR_ORIGINAL_SENDER_ADDRTYPE_W: int
PR_ORIGINAL_SENDER_ADDRTYPE_A: int
PR_ORIGINAL_SENDER_EMAIL_ADDRESS: int
PR_ORIGINAL_SENDER_EMAIL_ADDRESS_W: int
PR_ORIGINAL_SENDER_EMAIL_ADDRESS_A: int
PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE: int
PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_W: int
PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_A: int
PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS: int
PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_W: int
PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_A: int
PR_CONVERSATION_TOPIC: int
PR_CONVERSATION_TOPIC_W: int
PR_CONVERSATION_TOPIC_A: int
PR_CONVERSATION_INDEX: int
PR_ORIGINAL_DISPLAY_BCC: int
PR_ORIGINAL_DISPLAY_BCC_W: int
PR_ORIGINAL_DISPLAY_BCC_A: int
PR_ORIGINAL_DISPLAY_CC: int
PR_ORIGINAL_DISPLAY_CC_W: int
PR_ORIGINAL_DISPLAY_CC_A: int
PR_ORIGINAL_DISPLAY_TO: int
PR_ORIGINAL_DISPLAY_TO_W: int
PR_ORIGINAL_DISPLAY_TO_A: int
PR_RECEIVED_BY_ADDRTYPE: int
PR_RECEIVED_BY_ADDRTYPE_W: int
PR_RECEIVED_BY_ADDRTYPE_A: int
PR_RECEIVED_BY_EMAIL_ADDRESS: int
PR_RECEIVED_BY_EMAIL_ADDRESS_W: int
PR_RECEIVED_BY_EMAIL_ADDRESS_A: int
PR_RCVD_REPRESENTING_ADDRTYPE: int
PR_RCVD_REPRESENTING_ADDRTYPE_W: int
PR_RCVD_REPRESENTING_ADDRTYPE_A: int
PR_RCVD_REPRESENTING_EMAIL_ADDRESS: int
PR_RCVD_REPRESENTING_EMAIL_ADDRESS_W: int
PR_RCVD_REPRESENTING_EMAIL_ADDRESS_A: int
PR_ORIGINAL_AUTHOR_ADDRTYPE: int
PR_ORIGINAL_AUTHOR_ADDRTYPE_W: int
PR_ORIGINAL_AUTHOR_ADDRTYPE_A: int
PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS: int
PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_W: int
PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_A: int
PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE: int
PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_W: int
PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_A: int
PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS: int
PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_W: int
PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_A: int
PR_TRANSPORT_MESSAGE_HEADERS: int
PR_TRANSPORT_MESSAGE_HEADERS_W: int
PR_TRANSPORT_MESSAGE_HEADERS_A: int
PR_DELEGATION: int
PR_TNEF_CORRELATION_KEY: int
PR_BODY: int
PR_BODY_W: int
PR_BODY_A: int
PR_BODY_HTML: int
PR_BODY_HTML_W: int
PR_BODY_HTML_A: int
PR_REPORT_TEXT: int
PR_REPORT_TEXT_W: int
PR_REPORT_TEXT_A: int
PR_ORIGINATOR_AND_DL_EXPANSION_HISTORY: int
PR_REPORTING_DL_NAME: int
PR_REPORTING_MTA_CERTIFICATE: int
PR_RTF_SYNC_BODY_CRC: int
PR_RTF_SYNC_BODY_COUNT: int
PR_RTF_SYNC_BODY_TAG: int
PR_RTF_SYNC_BODY_TAG_W: int
PR_RTF_SYNC_BODY_TAG_A: int
PR_RTF_COMPRESSED: int
PR_RTF_SYNC_PREFIX_COUNT: int
PR_RTF_SYNC_TRAILING_COUNT: int
PR_ORIGINALLY_INTENDED_RECIP_ENTRYID: int
PR_CONTENT_INTEGRITY_CHECK: int
PR_EXPLICIT_CONVERSION: int
PR_IPM_RETURN_REQUESTED: int
PR_MESSAGE_TOKEN: int
PR_NDR_REASON_CODE: int
PR_NDR_DIAG_CODE: int
PR_NON_RECEIPT_NOTIFICATION_REQUESTED: int
PR_DELIVERY_POINT: int
PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED: int
PR_ORIGINATOR_REQUESTED_ALTERNATE_RECIPIENT: int
PR_PHYSICAL_DELIVERY_BUREAU_FAX_DELIVERY: int
PR_PHYSICAL_DELIVERY_MODE: int
PR_PHYSICAL_DELIVERY_REPORT_REQUEST: int
PR_PHYSICAL_FORWARDING_ADDRESS: int
PR_PHYSICAL_FORWARDING_ADDRESS_REQUESTED: int
PR_PHYSICAL_FORWARDING_PROHIBITED: int
PR_PHYSICAL_RENDITION_ATTRIBUTES: int
PR_PROOF_OF_DELIVERY: int
PR_PROOF_OF_DELIVERY_REQUESTED: int
PR_RECIPIENT_CERTIFICATE: int
PR_RECIPIENT_NUMBER_FOR_ADVICE: int
PR_RECIPIENT_NUMBER_FOR_ADVICE_W: int
PR_RECIPIENT_NUMBER_FOR_ADVICE_A: int
PR_RECIPIENT_TYPE: int
PR_REGISTERED_MAIL_TYPE: int
PR_REPLY_REQUESTED: int
PR_REQUESTED_DELIVERY_METHOD: int
PR_SENDER_ENTRYID: int
PR_SENDER_NAME: int
PR_SENDER_NAME_W: int
PR_SENDER_NAME_A: int
PR_SUPPLEMENTARY_INFO: int
PR_SUPPLEMENTARY_INFO_W: int
PR_SUPPLEMENTARY_INFO_A: int
PR_TYPE_OF_MTS_USER: int
PR_SENDER_SEARCH_KEY: int
PR_SENDER_ADDRTYPE: int
PR_SENDER_ADDRTYPE_W: int
PR_SENDER_ADDRTYPE_A: int
PR_SENDER_EMAIL_ADDRESS: int
PR_SENDER_EMAIL_ADDRESS_W: int
PR_SENDER_EMAIL_ADDRESS_A: int
PR_CURRENT_VERSION: int
PR_DELETE_AFTER_SUBMIT: int
PR_DISPLAY_BCC: int
PR_DISPLAY_BCC_W: int
PR_DISPLAY_BCC_A: int
PR_DISPLAY_CC: int
PR_DISPLAY_CC_W: int
PR_DISPLAY_CC_A: int
PR_DISPLAY_TO: int
PR_DISPLAY_TO_W: int
PR_DISPLAY_TO_A: int
PR_PARENT_DISPLAY: int
PR_PARENT_DISPLAY_W: int
PR_PARENT_DISPLAY_A: int
PR_MESSAGE_DELIVERY_TIME: int
PR_MESSAGE_FLAGS: int
PR_MESSAGE_SIZE: int
PR_PARENT_ENTRYID: int
PR_SENTMAIL_ENTRYID: int
PR_CORRELATE: int
PR_CORRELATE_MTSID: int
PR_DISCRETE_VALUES: int
PR_RESPONSIBILITY: int
PR_SPOOLER_STATUS: int
PR_TRANSPORT_STATUS: int
PR_MESSAGE_RECIPIENTS: int
PR_MESSAGE_ATTACHMENTS: int
PR_SUBMIT_FLAGS: int
PR_RECIPIENT_STATUS: int
PR_TRANSPORT_KEY: int
PR_MSG_STATUS: int
PR_MESSAGE_DOWNLOAD_TIME: int
PR_CREATION_VERSION: int
PR_MODIFY_VERSION: int
PR_HASATTACH: int
PR_BODY_CRC: int
PR_NORMALIZED_SUBJECT: int
PR_NORMALIZED_SUBJECT_W: int
PR_NORMALIZED_SUBJECT_A: int
PR_RTF_IN_SYNC: int
PR_ATTACH_SIZE: int
PR_ATTACH_NUM: int
PR_PREPROCESS: int
PR_ORIGINATING_MTA_CERTIFICATE: int
PR_PROOF_OF_SUBMISSION: int
PR_ENTRYID: int
PR_OBJECT_TYPE: int
PR_ICON: int
PR_MINI_ICON: int
PR_STORE_ENTRYID: int
PR_STORE_RECORD_KEY: int
PR_RECORD_KEY: int
PR_MAPPING_SIGNATURE: int
PR_ACCESS_LEVEL: int
PR_INSTANCE_KEY: int
PR_ROW_TYPE: int
PR_ACCESS: int
PR_ROWID: int
PR_DISPLAY_NAME: int
PR_DISPLAY_NAME_W: int
PR_DISPLAY_NAME_A: int
PR_ADDRTYPE: int
PR_ADDRTYPE_W: int
PR_ADDRTYPE_A: int
PR_EMAIL_ADDRESS: int
PR_EMAIL_ADDRESS_W: int
PR_EMAIL_ADDRESS_A: int
PR_COMMENT: int
PR_COMMENT_W: int
PR_COMMENT_A: int
PR_DEPTH: int
PR_PROVIDER_DISPLAY: int
PR_PROVIDER_DISPLAY_W: int
PR_PROVIDER_DISPLAY_A: int
PR_CREATION_TIME: int
PR_LAST_MODIFICATION_TIME: int
PR_RESOURCE_FLAGS: int
PR_PROVIDER_DLL_NAME: int
PR_PROVIDER_DLL_NAME_W: int
PR_PROVIDER_DLL_NAME_A: int
PR_SEARCH_KEY: int
PR_PROVIDER_UID: int
PR_PROVIDER_ORDINAL: int
PR_FORM_VERSION: int
PR_FORM_VERSION_W: int
PR_FORM_VERSION_A: int
PR_FORM_CLSID: int
PR_FORM_CONTACT_NAME: int
PR_FORM_CONTACT_NAME_W: int
PR_FORM_CONTACT_NAME_A: int
PR_FORM_CATEGORY: int
PR_FORM_CATEGORY_W: int
PR_FORM_CATEGORY_A: int
PR_FORM_CATEGORY_SUB: int
PR_FORM_CATEGORY_SUB_W: int
PR_FORM_CATEGORY_SUB_A: int
PR_FORM_HOST_MAP: int
PR_FORM_HIDDEN: int
PR_FORM_DESIGNER_NAME: int
PR_FORM_DESIGNER_NAME_W: int
PR_FORM_DESIGNER_NAME_A: int
PR_FORM_DESIGNER_GUID: int
PR_FORM_MESSAGE_BEHAVIOR: int
PR_DEFAULT_STORE: int
PR_STORE_SUPPORT_MASK: int
PR_STORE_STATE: int
PR_IPM_SUBTREE_SEARCH_KEY: int
PR_IPM_OUTBOX_SEARCH_KEY: int
PR_IPM_WASTEBASKET_SEARCH_KEY: int
PR_IPM_SENTMAIL_SEARCH_KEY: int
PR_MDB_PROVIDER: int
PR_RECEIVE_FOLDER_SETTINGS: int
PR_VALID_FOLDER_MASK: int
PR_IPM_SUBTREE_ENTRYID: int
PR_IPM_OUTBOX_ENTRYID: int
PR_IPM_WASTEBASKET_ENTRYID: int
PR_IPM_SENTMAIL_ENTRYID: int
PR_VIEWS_ENTRYID: int
PR_COMMON_VIEWS_ENTRYID: int
PR_FINDER_ENTRYID: int
PR_CONTAINER_FLAGS: int
PR_FOLDER_TYPE: int
PR_CONTENT_COUNT: int
PR_CONTENT_UNREAD: int
PR_CREATE_TEMPLATES: int
PR_DETAILS_TABLE: int
PR_SEARCH: int
PR_SELECTABLE: int
PR_SUBFOLDERS: int
PR_STATUS: int
PR_ANR: int
PR_ANR_W: int
PR_ANR_A: int
PR_CONTENTS_SORT_ORDER: int
PR_CONTAINER_HIERARCHY: int
PR_CONTAINER_CONTENTS: int
PR_FOLDER_ASSOCIATED_CONTENTS: int
PR_DEF_CREATE_DL: int
PR_DEF_CREATE_MAILUSER: int
PR_CONTAINER_CLASS: int
PR_CONTAINER_CLASS_W: int
PR_CONTAINER_CLASS_A: int
PR_CONTAINER_MODIFY_VERSION: int
PR_AB_PROVIDER_ID: int
PR_DEFAULT_VIEW_ENTRYID: int
PR_ASSOC_CONTENT_COUNT: int
PR_ATTACHMENT_X400_PARAMETERS: int
PR_ATTACH_DATA_OBJ: int
PR_ATTACH_DATA_BIN: int
PR_ATTACH_ENCODING: int
PR_ATTACH_EXTENSION: int
PR_ATTACH_EXTENSION_W: int
PR_ATTACH_EXTENSION_A: int
PR_ATTACH_FILENAME: int
PR_ATTACH_FILENAME_W: int
PR_ATTACH_FILENAME_A: int
PR_ATTACH_METHOD: int
PR_ATTACH_LONG_FILENAME: int
PR_ATTACH_LONG_FILENAME_W: int
PR_ATTACH_LONG_FILENAME_A: int
PR_ATTACH_PATHNAME: int
PR_ATTACH_PATHNAME_W: int
PR_ATTACH_PATHNAME_A: int
PR_ATTACH_RENDERING: int
PR_ATTACH_TAG: int
PR_RENDERING_POSITION: int
PR_ATTACH_TRANSPORT_NAME: int
PR_ATTACH_TRANSPORT_NAME_W: int
PR_ATTACH_TRANSPORT_NAME_A: int
PR_ATTACH_LONG_PATHNAME: int
PR_ATTACH_LONG_PATHNAME_W: int
PR_ATTACH_LONG_PATHNAME_A: int
PR_ATTACH_MIME_TAG: int
PR_ATTACH_MIME_TAG_W: int
PR_ATTACH_MIME_TAG_A: int
PR_ATTACH_ADDITIONAL_INFO: int
PR_DISPLAY_TYPE: int
PR_TEMPLATEID: int
PR_PRIMARY_CAPABILITY: int
PR_7BIT_DISPLAY_NAME: int
PR_ACCOUNT: int
PR_ACCOUNT_W: int
PR_ACCOUNT_A: int
PR_ALTERNATE_RECIPIENT: int
PR_CALLBACK_TELEPHONE_NUMBER: int
PR_CALLBACK_TELEPHONE_NUMBER_W: int
PR_CALLBACK_TELEPHONE_NUMBER_A: int
PR_CONVERSION_PROHIBITED: int
PR_DISCLOSE_RECIPIENTS: int
PR_GENERATION: int
PR_GENERATION_W: int
PR_GENERATION_A: int
PR_GIVEN_NAME: int
PR_GIVEN_NAME_W: int
PR_GIVEN_NAME_A: int
PR_GOVERNMENT_ID_NUMBER: int
PR_GOVERNMENT_ID_NUMBER_W: int
PR_GOVERNMENT_ID_NUMBER_A: int
PR_BUSINESS_TELEPHONE_NUMBER: int
PR_BUSINESS_TELEPHONE_NUMBER_W: int
PR_BUSINESS_TELEPHONE_NUMBER_A: int
PR_OFFICE_TELEPHONE_NUMBER: int
PR_OFFICE_TELEPHONE_NUMBER_W: int
PR_OFFICE_TELEPHONE_NUMBER_A: int
PR_HOME_TELEPHONE_NUMBER: int
PR_HOME_TELEPHONE_NUMBER_W: int
PR_HOME_TELEPHONE_NUMBER_A: int
PR_INITIALS: int
PR_INITIALS_W: int
PR_INITIALS_A: int
PR_KEYWORD: int
PR_KEYWORD_W: int
PR_KEYWORD_A: int
PR_LANGUAGE: int
PR_LANGUAGE_W: int
PR_LANGUAGE_A: int
PR_LOCATION: int
PR_LOCATION_W: int
PR_LOCATION_A: int
PR_MAIL_PERMISSION: int
PR_MHS_COMMON_NAME: int
PR_MHS_COMMON_NAME_W: int
PR_MHS_COMMON_NAME_A: int
PR_ORGANIZATIONAL_ID_NUMBER: int
PR_ORGANIZATIONAL_ID_NUMBER_W: int
PR_ORGANIZATIONAL_ID_NUMBER_A: int
PR_SURNAME: int
PR_SURNAME_W: int
PR_SURNAME_A: int
PR_ORIGINAL_ENTRYID: int
PR_ORIGINAL_DISPLAY_NAME: int
PR_ORIGINAL_DISPLAY_NAME_W: int
PR_ORIGINAL_DISPLAY_NAME_A: int
PR_ORIGINAL_SEARCH_KEY: int
PR_POSTAL_ADDRESS: int
PR_POSTAL_ADDRESS_W: int
PR_POSTAL_ADDRESS_A: int
PR_COMPANY_NAME: int
PR_COMPANY_NAME_W: int
PR_COMPANY_NAME_A: int
PR_TITLE: int
PR_TITLE_W: int
PR_TITLE_A: int
PR_DEPARTMENT_NAME: int
PR_DEPARTMENT_NAME_W: int
PR_DEPARTMENT_NAME_A: int
PR_OFFICE_LOCATION: int
PR_OFFICE_LOCATION_W: int
PR_OFFICE_LOCATION_A: int
PR_PRIMARY_TELEPHONE_NUMBER: int
PR_PRIMARY_TELEPHONE_NUMBER_W: int
PR_PRIMARY_TELEPHONE_NUMBER_A: int
PR_BUSINESS2_TELEPHONE_NUMBER: int
PR_BUSINESS2_TELEPHONE_NUMBER_W: int
PR_BUSINESS2_TELEPHONE_NUMBER_A: int
PR_OFFICE2_TELEPHONE_NUMBER: int
PR_OFFICE2_TELEPHONE_NUMBER_W: int
PR_OFFICE2_TELEPHONE_NUMBER_A: int
PR_MOBILE_TELEPHONE_NUMBER: int
PR_MOBILE_TELEPHONE_NUMBER_W: int
PR_MOBILE_TELEPHONE_NUMBER_A: int
PR_CELLULAR_TELEPHONE_NUMBER: int
PR_CELLULAR_TELEPHONE_NUMBER_W: int
PR_CELLULAR_TELEPHONE_NUMBER_A: int
PR_RADIO_TELEPHONE_NUMBER: int
PR_RADIO_TELEPHONE_NUMBER_W: int
PR_RADIO_TELEPHONE_NUMBER_A: int
PR_CAR_TELEPHONE_NUMBER: int
PR_CAR_TELEPHONE_NUMBER_W: int
PR_CAR_TELEPHONE_NUMBER_A: int
PR_OTHER_TELEPHONE_NUMBER: int
PR_OTHER_TELEPHONE_NUMBER_W: int
PR_OTHER_TELEPHONE_NUMBER_A: int
PR_TRANSMITABLE_DISPLAY_NAME: int
PR_TRANSMITABLE_DISPLAY_NAME_W: int
PR_TRANSMITABLE_DISPLAY_NAME_A: int
PR_PAGER_TELEPHONE_NUMBER: int
PR_PAGER_TELEPHONE_NUMBER_W: int
PR_PAGER_TELEPHONE_NUMBER_A: int
PR_BEEPER_TELEPHONE_NUMBER: int
PR_BEEPER_TELEPHONE_NUMBER_W: int
PR_BEEPER_TELEPHONE_NUMBER_A: int
PR_USER_CERTIFICATE: int
PR_PRIMARY_FAX_NUMBER: int
PR_PRIMARY_FAX_NUMBER_W: int
PR_PRIMARY_FAX_NUMBER_A: int
PR_BUSINESS_FAX_NUMBER: int
PR_BUSINESS_FAX_NUMBER_W: int
PR_BUSINESS_FAX_NUMBER_A: int
PR_HOME_FAX_NUMBER: int
PR_HOME_FAX_NUMBER_W: int
PR_HOME_FAX_NUMBER_A: int
PR_COUNTRY: int
PR_COUNTRY_W: int
PR_COUNTRY_A: int
PR_BUSINESS_ADDRESS_COUNTRY: int
PR_BUSINESS_ADDRESS_COUNTRY_W: int
PR_BUSINESS_ADDRESS_COUNTRY_A: int
PR_LOCALITY: int
PR_LOCALITY_W: int
PR_LOCALITY_A: int
PR_BUSINESS_ADDRESS_CITY: int
PR_BUSINESS_ADDRESS_CITY_W: int
PR_BUSINESS_ADDRESS_CITY_A: int
PR_STATE_OR_PROVINCE: int
PR_STATE_OR_PROVINCE_W: int
PR_STATE_OR_PROVINCE_A: int
PR_BUSINESS_ADDRESS_STATE_OR_PROVINCE: int
PR_BUSINESS_ADDRESS_STATE_OR_PROVINCE_W: int
PR_BUSINESS_ADDRESS_STATE_OR_PROVINCE_A: int
PR_STREET_ADDRESS: int
PR_STREET_ADDRESS_W: int
PR_STREET_ADDRESS_A: int
PR_BUSINESS_ADDRESS_STREET: int
PR_BUSINESS_ADDRESS_STREET_W: int
PR_BUSINESS_ADDRESS_STREET_A: int
PR_POSTAL_CODE: int
PR_POSTAL_CODE_W: int
PR_POSTAL_CODE_A: int
PR_BUSINESS_ADDRESS_POSTAL_CODE: int
PR_BUSINESS_ADDRESS_POSTAL_CODE_W: int
PR_BUSINESS_ADDRESS_POSTAL_CODE_A: int
PR_POST_OFFICE_BOX: int
PR_POST_OFFICE_BOX_W: int
PR_POST_OFFICE_BOX_A: int
PR_BUSINESS_ADDRESS_POST_OFFICE_BOX: int
PR_BUSINESS_ADDRESS_POST_OFFICE_BOX_W: int
PR_BUSINESS_ADDRESS_POST_OFFICE_BOX_A: int
PR_TELEX_NUMBER: int
PR_TELEX_NUMBER_W: int
PR_TELEX_NUMBER_A: int
PR_ISDN_NUMBER: int
PR_ISDN_NUMBER_W: int
PR_ISDN_NUMBER_A: int
PR_ASSISTANT_TELEPHONE_NUMBER: int
PR_ASSISTANT_TELEPHONE_NUMBER_W: int
PR_ASSISTANT_TELEPHONE_NUMBER_A: int
PR_HOME2_TELEPHONE_NUMBER: int
PR_HOME2_TELEPHONE_NUMBER_W: int
PR_HOME2_TELEPHONE_NUMBER_A: int
PR_ASSISTANT: int
PR_ASSISTANT_W: int
PR_ASSISTANT_A: int
PR_SEND_RICH_INFO: int
PR_WEDDING_ANNIVERSARY: int
PR_BIRTHDAY: int
PR_HOBBIES: int
PR_HOBBIES_W: int
PR_HOBBIES_A: int
PR_MIDDLE_NAME: int
PR_MIDDLE_NAME_W: int
PR_MIDDLE_NAME_A: int
PR_DISPLAY_NAME_PREFIX: int
PR_DISPLAY_NAME_PREFIX_W: int
PR_DISPLAY_NAME_PREFIX_A: int
PR_PROFESSION: int
PR_PROFESSION_W: int
PR_PROFESSION_A: int
PR_PREFERRED_BY_NAME: int
PR_PREFERRED_BY_NAME_W: int
PR_PREFERRED_BY_NAME_A: int
PR_SPOUSE_NAME: int
PR_SPOUSE_NAME_W: int
PR_SPOUSE_NAME_A: int
PR_COMPUTER_NETWORK_NAME: int
PR_COMPUTER_NETWORK_NAME_W: int
PR_COMPUTER_NETWORK_NAME_A: int
PR_CUSTOMER_ID: int
PR_CUSTOMER_ID_W: int
PR_CUSTOMER_ID_A: int
PR_TTYTDD_PHONE_NUMBER: int
PR_TTYTDD_PHONE_NUMBER_W: int
PR_TTYTDD_PHONE_NUMBER_A: int
PR_FTP_SITE: int
PR_FTP_SITE_W: int
PR_FTP_SITE_A: int
PR_GENDER: int
PR_MANAGER_NAME: int
PR_MANAGER_NAME_W: int
PR_MANAGER_NAME_A: int
PR_NICKNAME: int
PR_NICKNAME_W: int
PR_NICKNAME_A: int
PR_PERSONAL_HOME_PAGE: int
PR_PERSONAL_HOME_PAGE_W: int
PR_PERSONAL_HOME_PAGE_A: int
PR_BUSINESS_HOME_PAGE: int
PR_BUSINESS_HOME_PAGE_W: int
PR_BUSINESS_HOME_PAGE_A: int
PR_CONTACT_VERSION: int
PR_CONTACT_ENTRYIDS: int
PR_CONTACT_ADDRTYPES: int
PR_CONTACT_ADDRTYPES_W: int
PR_CONTACT_ADDRTYPES_A: int
PR_CONTACT_DEFAULT_ADDRESS_INDEX: int
PR_CONTACT_EMAIL_ADDRESSES: int
PR_CONTACT_EMAIL_ADDRESSES_W: int
PR_CONTACT_EMAIL_ADDRESSES_A: int
PR_COMPANY_MAIN_PHONE_NUMBER: int
PR_COMPANY_MAIN_PHONE_NUMBER_W: int
PR_COMPANY_MAIN_PHONE_NUMBER_A: int
PR_CHILDRENS_NAMES: int
PR_CHILDRENS_NAMES_W: int
PR_CHILDRENS_NAMES_A: int
PR_HOME_ADDRESS_CITY: int
PR_HOME_ADDRESS_CITY_W: int
PR_HOME_ADDRESS_CITY_A: int
PR_HOME_ADDRESS_COUNTRY: int
PR_HOME_ADDRESS_COUNTRY_W: int
PR_HOME_ADDRESS_COUNTRY_A: int
PR_HOME_ADDRESS_POSTAL_CODE: int
PR_HOME_ADDRESS_POSTAL_CODE_W: int
PR_HOME_ADDRESS_POSTAL_CODE_A: int
PR_HOME_ADDRESS_STATE_OR_PROVINCE: int
PR_HOME_ADDRESS_STATE_OR_PROVINCE_W: int
PR_HOME_ADDRESS_STATE_OR_PROVINCE_A: int
PR_HOME_ADDRESS_STREET: int
PR_HOME_ADDRESS_STREET_W: int
PR_HOME_ADDRESS_STREET_A: int
PR_HOME_ADDRESS_POST_OFFICE_BOX: int
PR_HOME_ADDRESS_POST_OFFICE_BOX_W: int
PR_HOME_ADDRESS_POST_OFFICE_BOX_A: int
PR_OTHER_ADDRESS_CITY: int
PR_OTHER_ADDRESS_CITY_W: int
PR_OTHER_ADDRESS_CITY_A: int
PR_OTHER_ADDRESS_COUNTRY: int
PR_OTHER_ADDRESS_COUNTRY_W: int
PR_OTHER_ADDRESS_COUNTRY_A: int
PR_OTHER_ADDRESS_POSTAL_CODE: int
PR_OTHER_ADDRESS_POSTAL_CODE_W: int
PR_OTHER_ADDRESS_POSTAL_CODE_A: int
PR_OTHER_ADDRESS_STATE_OR_PROVINCE: int
PR_OTHER_ADDRESS_STATE_OR_PROVINCE_W: int
PR_OTHER_ADDRESS_STATE_OR_PROVINCE_A: int
PR_OTHER_ADDRESS_STREET: int
PR_OTHER_ADDRESS_STREET_W: int
PR_OTHER_ADDRESS_STREET_A: int
PR_OTHER_ADDRESS_POST_OFFICE_BOX: int
PR_OTHER_ADDRESS_POST_OFFICE_BOX_W: int
PR_OTHER_ADDRESS_POST_OFFICE_BOX_A: int
PR_STORE_PROVIDERS: int
PR_AB_PROVIDERS: int
PR_TRANSPORT_PROVIDERS: int
PR_DEFAULT_PROFILE: int
PR_AB_SEARCH_PATH: int
PR_AB_DEFAULT_DIR: int
PR_AB_DEFAULT_PAB: int
PR_FILTERING_HOOKS: int
PR_SERVICE_NAME: int
PR_SERVICE_NAME_W: int
PR_SERVICE_NAME_A: int
PR_SERVICE_DLL_NAME: int
PR_SERVICE_DLL_NAME_W: int
PR_SERVICE_DLL_NAME_A: int
PR_SERVICE_ENTRY_NAME: int
PR_SERVICE_UID: int
PR_SERVICE_EXTRA_UIDS: int
PR_SERVICES: int
PR_SERVICE_SUPPORT_FILES: int
PR_SERVICE_SUPPORT_FILES_W: int
PR_SERVICE_SUPPORT_FILES_A: int
PR_SERVICE_DELETE_FILES: int
PR_SERVICE_DELETE_FILES_W: int
PR_SERVICE_DELETE_FILES_A: int
PR_AB_SEARCH_PATH_UPDATE: int
PR_PROFILE_NAME: int
PR_PROFILE_NAME_A: int
PR_PROFILE_NAME_W: int
PR_IDENTITY_DISPLAY: int
PR_IDENTITY_DISPLAY_W: int
PR_IDENTITY_DISPLAY_A: int
PR_IDENTITY_ENTRYID: int
PR_RESOURCE_METHODS: int
PR_RESOURCE_TYPE: int
PR_STATUS_CODE: int
PR_IDENTITY_SEARCH_KEY: int
PR_OWN_STORE_ENTRYID: int
PR_RESOURCE_PATH: int
PR_RESOURCE_PATH_W: int
PR_RESOURCE_PATH_A: int
PR_STATUS_STRING: int
PR_STATUS_STRING_W: int
PR_STATUS_STRING_A: int
PR_X400_DEFERRED_DELIVERY_CANCEL: int
PR_HEADER_FOLDER_ENTRYID: int
PR_REMOTE_PROGRESS: int
PR_REMOTE_PROGRESS_TEXT: int
PR_REMOTE_PROGRESS_TEXT_W: int
PR_REMOTE_PROGRESS_TEXT_A: int
PR_REMOTE_VALIDATE_OK: int
PR_CONTROL_FLAGS: int
PR_CONTROL_STRUCTURE: int
PR_CONTROL_TYPE: int
PR_DELTAX: int
PR_DELTAY: int
PR_XPOS: int
PR_YPOS: int
PR_CONTROL_ID: int
PR_INITIAL_DETAILS_PANE: int
PROP_ID_SECURE_MIN: int
PROP_ID_SECURE_MAX: int
pidExchangeXmitReservedMin: int
pidExchangeNonXmitReservedMin: int
pidProfileMin: int
pidStoreMin: int
pidFolderMin: int
pidMessageReadOnlyMin: int
pidMessageWriteableMin: int
pidAttachReadOnlyMin: int
pidSpecialMin: int
pidAdminMin: int
pidSecureProfileMin: int
PR_PROFILE_VERSION: int
PR_PROFILE_CONFIG_FLAGS: int
PR_PROFILE_HOME_SERVER: int
PR_PROFILE_HOME_SERVER_DN: int
PR_PROFILE_HOME_SERVER_ADDRS: int
PR_PROFILE_USER: int
PR_PROFILE_CONNECT_FLAGS: int
PR_PROFILE_TRANSPORT_FLAGS: int
PR_PROFILE_UI_STATE: int
PR_PROFILE_UNRESOLVED_NAME: int
PR_PROFILE_UNRESOLVED_SERVER: int
PR_PROFILE_BINDING_ORDER: int
PR_PROFILE_MAX_RESTRICT: int
PR_PROFILE_AB_FILES_PATH: int
PR_PROFILE_OFFLINE_STORE_PATH: int
PR_PROFILE_OFFLINE_INFO: int
PR_PROFILE_ADDR_INFO: int
PR_PROFILE_OPTIONS_DATA: int
PR_PROFILE_SECURE_MAILBOX: int
PR_DISABLE_WINSOCK: int
PR_OST_ENCRYPTION: int
PR_PROFILE_OPEN_FLAGS: int
PR_PROFILE_TYPE: int
PR_PROFILE_MAILBOX: int
PR_PROFILE_SERVER: int
PR_PROFILE_SERVER_DN: int
PR_PROFILE_FAVFLD_DISPLAY_NAME: int
PR_PROFILE_FAVFLD_COMMENT: int
PR_PROFILE_ALLPUB_DISPLAY_NAME: int
PR_PROFILE_ALLPUB_COMMENT: int
OSTF_NO_ENCRYPTION: int
OSTF_COMPRESSABLE_ENCRYPTION: int
OSTF_BEST_ENCRYPTION: int
PR_NON_IPM_SUBTREE_ENTRYID: int
PR_EFORMS_REGISTRY_ENTRYID: int
PR_SPLUS_FREE_BUSY_ENTRYID: int
PR_OFFLINE_ADDRBOOK_ENTRYID: int
PR_EFORMS_FOR_LOCALE_ENTRYID: int
PR_FREE_BUSY_FOR_LOCAL_SITE_ENTRYID: int
PR_ADDRBOOK_FOR_LOCAL_SITE_ENTRYID: int
PR_OFFLINE_MESSAGE_ENTRYID: int
PR_IPM_FAVORITES_ENTRYID: int
PR_IPM_PUBLIC_FOLDERS_ENTRYID: int
PR_GW_MTSIN_ENTRYID: int
PR_GW_MTSOUT_ENTRYID: int
PR_TRANSFER_ENABLED: int
PR_TEST_LINE_SPEED: int
PR_HIERARCHY_SYNCHRONIZER: int
PR_CONTENTS_SYNCHRONIZER: int
PR_COLLECTOR: int
PR_FAST_TRANSFER: int
PR_STORE_OFFLINE: int
PR_IN_TRANSIT: int
PR_REPLICATION_STYLE: int
PR_REPLICATION_SCHEDULE: int
PR_REPLICATION_MESSAGE_PRIORITY: int
PR_OVERALL_MSG_AGE_LIMIT: int
PR_REPLICATION_ALWAYS_INTERVAL: int
PR_REPLICATION_MSG_SIZE: int
STYLE_ALWAYS_INTERVAL_DEFAULT: int
REPLICATION_MESSAGE_SIZE_LIMIT_DEFAULT: int
STYLE_NEVER: int
STYLE_NORMAL: int
STYLE_ALWAYS: int
STYLE_DEFAULT: int
PR_SOURCE_KEY: int
PR_PARENT_SOURCE_KEY: int
PR_CHANGE_KEY: int
PR_PREDECESSOR_CHANGE_LIST: int
PR_FOLDER_CHILD_COUNT: int
PR_RIGHTS: int
PR_ACL_TABLE: int
PR_RULES_TABLE: int
PR_HAS_RULES: int
PR_ADDRESS_BOOK_ENTRYID: int
PR_ACL_DATA: int
PR_RULES_DATA: int
PR_FOLDER_DESIGN_FLAGS: int
PR_DESIGN_IN_PROGRESS: int
PR_SECURE_ORIGINATION: int
PR_PUBLISH_IN_ADDRESS_BOOK: int
PR_RESOLVE_METHOD: int
PR_ADDRESS_BOOK_DISPLAY_NAME: int
PR_EFORMS_LOCALE_ID: int
PR_REPLICA_LIST: int
PR_OVERALL_AGE_LIMIT: int
RESOLVE_METHOD_DEFAULT: int
RESOLVE_METHOD_LAST_WRITER_WINS: int
RESOLVE_METHOD_NO_CONFLICT_NOTIFICATION: int
PR_PUBLIC_FOLDER_ENTRYID: int
PR_HAS_NAMED_PROPERTIES: int
PR_CREATOR_NAME: int
PR_CREATOR_ENTRYID: int
PR_LAST_MODIFIER_NAME: int
PR_LAST_MODIFIER_ENTRYID: int
PR_HAS_DAMS: int
PR_RULE_TRIGGER_HISTORY: int
PR_MOVE_TO_STORE_ENTRYID: int
PR_MOVE_TO_FOLDER_ENTRYID: int
PR_REPLICA_SERVER: int
PR_DEFERRED_SEND_NUMBER: int
PR_DEFERRED_SEND_UNITS: int
PR_EXPIRY_NUMBER: int
PR_EXPIRY_UNITS: int
PR_DEFERRED_SEND_TIME: int
PR_GW_ADMIN_OPERATIONS: int
PR_P1_CONTENT: int
PR_P1_CONTENT_TYPE: int
PR_CLIENT_ACTIONS: int
PR_DAM_ORIGINAL_ENTRYID: int
PR_DAM_BACK_PATCHED: int
PR_RULE_ERROR: int
PR_RULE_ACTION_TYPE: int
PR_RULE_ACTION_NUMBER: int
PR_RULE_FOLDER_ENTRYID: int
PR_CONFLICT_ENTRYID: int
PR_MESSAGE_LOCALE_ID: int
PR_STORAGE_QUOTA_LIMIT: int
PR_EXCESS_STORAGE_USED: int
PR_SVR_GENERATING_QUOTA_MSG: int
PR_DELEGATED_BY_RULE: int
MSGSTATUS_IN_CONFLICT: int
PR_IN_CONFLICT: int
PR_LONGTERM_ENTRYID_FROM_TABLE: int
PR_ORIGINATOR_NAME: int
PR_ORIGINATOR_ADDR: int
PR_ORIGINATOR_ADDRTYPE: int
PR_ORIGINATOR_ENTRYID: int
PR_ARRIVAL_TIME: int
PR_TRACE_INFO: int
PR_INTERNAL_TRACE_INFO: int
PR_SUBJECT_TRACE_INFO: int
PR_RECIPIENT_NUMBER: int
PR_MTS_SUBJECT_ID: int
PR_REPORT_DESTINATION_NAME: int
PR_REPORT_DESTINATION_ENTRYID: int
PR_CONTENT_SEARCH_KEY: int
PR_FOREIGN_ID: int
PR_FOREIGN_REPORT_ID: int
PR_FOREIGN_SUBJECT_ID: int
PR_MTS_ID: int
PR_MTS_REPORT_ID: int
PR_FOLDER_FLAGS: int
PR_LAST_ACCESS_TIME: int
PR_RESTRICTION_COUNT: int
PR_CATEG_COUNT: int
PR_CACHED_COLUMN_COUNT: int
PR_NORMAL_MSG_W_ATTACH_COUNT: int
PR_ASSOC_MSG_W_ATTACH_COUNT: int
PR_RECIPIENT_ON_NORMAL_MSG_COUNT: int
PR_RECIPIENT_ON_ASSOC_MSG_COUNT: int
PR_ATTACH_ON_NORMAL_MSG_COUNT: int
PR_ATTACH_ON_ASSOC_MSG_COUNT: int
PR_NORMAL_MESSAGE_SIZE: int
PR_NORMAL_MESSAGE_SIZE_EXTENDED: int
PR_ASSOC_MESSAGE_SIZE: int
PR_ASSOC_MESSAGE_SIZE_EXTENDED: int
PR_FOLDER_PATHNAME: int
PR_OWNER_COUNT: int
PR_CONTACT_COUNT: int
PR_MESSAGE_SIZE_EXTENDED: int
PR_USERFIELDS: int
PR_FORCE_USE_ENTRYID_SERVER: int
PR_PROFILE_MDB_DN: int
PST_EXTERN_PROPID_BASE: int
PR_PST_PATH: int
PR_PST_PATH_W: int
PR_PST_PATH_A: int
PR_PST_REMEMBER_PW: int
PR_PST_ENCRYPTION: int
PR_PST_PW_SZ_OLD: int
PR_PST_PW_SZ_OLD_W: int
PR_PST_PW_SZ_OLD_A: int
PR_PST_PW_SZ_NEW: int
PR_PST_PW_SZ_NEW_W: int
PR_PST_PW_SZ_NEW_A: int
